@@ -38,7 +38,7 @@
 # Standardized arguments
 # ----------------------
 #
-# Input arguments passed to 2D plot commands are now uniformly
+# Data arguments passed to 2D plot commands are now uniformly
 # standardized. For each command, you can optionally omit the *x* and
 # *y* coordinates, in which case they are inferred from the data
 # (see :ref:`xarray and pandas integration <ug_2dintegration>`). If coordinates
@@ -115,7 +115,7 @@ axs[0].fill_between(
 )
 for i, ax in enumerate(axs):
     inbounds = i == 1
-    title = f'Manual limits inbounds={inbounds}'
+    title = f'Restricted lims inbounds={inbounds}'
     title += ' (default)' if inbounds else ''
     ax.format(
         xlim=(None if i == 0 else xlim),
@@ -146,9 +146,9 @@ fig.format(
 #
 # These features restore some of the convenience you get with the builtin
 # `pandas`_ and `xarray`_ plotting functions. They are also *optional* --
-# installation of pandas and xarray are not required to use proplot. All of these
-# features can be disabled by setting :rcraw:`autoformat` to ``False`` or by
-# passing ``autoformat=False`` to any plotting command.
+# installation of pandas and xarray are not required to use proplot. The
+# automatic labels can be disabled by setting :rcraw:`autoformat` to ``False``
+# or by passing ``autoformat=False`` to any plotting command.
 #
 # .. note::
 #
@@ -203,25 +203,23 @@ df.columns.name = 'variable (units)'
 
 # %%
 import proplot as pplt
-fig = pplt.figure(refwidth=2.5, share=False)
-fig.format(suptitle='Automatic subplot formatting')
+fig = pplt.figure(refwidth=2.5, share=False, suptitle='Automatic subplot formatting')
 
 # Plot DataArray
 cmap = pplt.Colormap('PuBu', left=0.05)
-ax = fig.subplot(121)
+ax = fig.subplot(121, yreverse=True)
 ax.contourf(da, cmap=cmap, colorbar='t', lw=0.7, ec='k')
-ax.format(yreverse=True)
 
 # Plot DataFrame
-ax = fig.subplot(122)
+ax = fig.subplot(122, yreverse=True)
 ax.contourf(df, cmap='YlOrRd', colorbar='t', lw=0.7, ec='k')
-ax.format(xtickminor=False, yreverse=True, yformatter='%b', ytickminor=False)
+ax.format(xtickminor=False, yformatter='%b', ytickminor=False)
 
 # %% [raw] raw_mimetype="text/restructuredtext"
 # .. _ug_apply_cmap:
 #
-# Colormaps and normalizers
-# -------------------------
+# Changing the colormap
+# ---------------------
 #
 # It is often useful to create `~proplot.colors.ContinuousColormap`\ s
 # on-the-fly, without explicitly calling the `~proplot.constructor.Colormap`
@@ -232,23 +230,11 @@ ax.format(xtickminor=False, yreverse=True, yformatter='%b', ytickminor=False)
 # You can also create on-the-fly "qualitative" `~proplot.colors.DiscreteColormap`\ s
 # by passing lists of colors to the keyword `c`, `color`, or `colors`.
 #
-# In matplotlib, data values are translated into
-# colormap colors using so-called `colormap "normalizers"
-# <https://matplotlib.org/stable/tutorials/colors/colormapnorms.html>`__.
-# A normalizer can be selected from its "registered" name using the
-# `~proplot.constructor.Norm` :ref:`constructor function <why_constructor>`. You
-# can also build a normalizer on-the-fly using the `norm` and `norm_kw` keywords,
-# again available with most `~proplot.axes.PlotAxes` 2D plot commands.
-# If you want to work with the normalizer classes directly, they are available in
-# the top-level namespace (e.g., ``norm=pplt.LogNorm(...)`` is allowed). To
-# explicitly set the normalization range, you can pass the usual `vmin` and `vmax`
-# keywords to the plotting command. See the :ref:`next section <ug_discrete>` for
-# more details on colormap normalization.
-#
-# To apply the default sequential, diverging, cyclic, or qualitative colormap to
-# a plot, pass ``sequential=True``, ``diverging=True``, ``cyclic=True``, or
-# ``qualitative=True`` to any plotting command. The default colormaps of each
-# type are :rc:`cmap.sequential`, :rc:`cmap.diverging`, :rc:`cmap.cyclic`, and
+# To apply the default :ref:`sequential, diverging, cyclic <ug_cmaps_included>`,
+# or :ref:`qualitative <ug_cycles_included>` colormap, pass ``sequential=True``,
+# ``diverging=True``, ``cyclic=True``, or ``qualitative=True`` to any plotting
+# command. The default colormaps of each type are specified with the proplot
+# settings :rc:`cmap.sequential`, :rc:`cmap.diverging`, :rc:`cmap.cyclic`, and
 # :rc:`cmap.qualitative`. Unless otherwise specified, the sequential colormap
 # is used with the default (linear) normalizer when data is strictly positive
 # or negative, and the diverging colormap is used when the data limits or
@@ -258,201 +244,99 @@ ax.format(xtickminor=False, yreverse=True, yformatter='%b', ytickminor=False)
 import proplot as pplt
 import numpy as np
 
+# Sample data
+N = 18
+state = np.random.RandomState(51423)
+data = np.cumsum(state.rand(N, N), axis=0)
+
+# Custom defaults of each type
+pplt.rc['cmap.sequential'] = 'PuBuGn'
+pplt.rc['cmap.diverging'] = 'PiYG'
+pplt.rc['cmap.cyclic'] = 'bamO'
+pplt.rc['cmap.qualitative'] = 'flatui'
+
+# Make plots. Note the default behavior is sequential=True or diverging=True
+# depending on whether data contains negative values (see below).
+fig = pplt.figure(refwidth=2.2, span=False, suptitle='Colormap types')
+axs = fig.subplots(ncols=2, nrows=2)
+axs.format(xformatter='none', yformatter='none')
+axs[0].pcolor(data, sequential=True, colorbar='l', extend='max')
+axs[1].pcolor(data - 5, diverging=True, colorbar='r', extend='both')
+axs[2].pcolor(data % 8, cyclic=True, colorbar='l')
+axs[3].pcolor(data, levels=pplt.arange(0, 12, 2), qualitative=True, colorbar='r')
+types = ('sequential', 'diverging', 'cyclic', 'qualitative')
+for ax, typ in zip(axs, types):
+    ax.format(title=typ.title() + ' colormap')
+pplt.rc.reset()
+
+# %%
+import proplot as pplt
+import numpy as np
+
+# Sample data
+N = 20
+state = np.random.RandomState(51423)
+data = np.cumsum(state.rand(N, N), axis=1) - 6
+
+# Continuous "diverging" colormap
+fig = pplt.figure(refwidth=2.3, spanx=False)
+ax = fig.subplot(121, title="Diverging colormap with 'cmap'", xlabel='xlabel')
+ax.contourf(
+    data,
+    norm='div',
+    cmap=('cobalt', 'white', 'violet red'),
+    cmap_kw={'space': 'hsl', 'cut': 0.15},
+    colorbar='b',
+)
+
+# Discrete "qualitative" colormap
+ax = fig.subplot(122, title="Qualitative colormap with 'colors'")
+ax.contourf(
+    data,
+    levels=pplt.arange(-6, 9, 3),
+    colors=['red5', 'blue5', 'yellow5', 'gray5', 'violet5'],
+    colorbar='b',
+)
+fig.format(xlabel='xlabel', ylabel='ylabel', suptitle='On-the-fly colormaps')
+
+# %% [raw] raw_mimetype="text/restructuredtext"
+# .. _ug_apply_norm:
+#
+# Changing the normalizer
+# -----------------------
+#
+# Matplotlib `colormap "normalizers"
+# <https://matplotlib.org/stable/tutorials/colors/colormapnorms.html>`__
+# translate raw data values into normalized colormap indices. In proplot,
+# you can select the normalizer from its "registered" name using the
+# `~proplot.constructor.Norm` :ref:`constructor function <why_constructor>`. You
+# can also build a normalizer on-the-fly using the `norm` and `norm_kw` keywords,
+# available with most `~proplot.axes.PlotAxes` 2D plot commands.
+# If you want to work with the normalizer classes directly, they are available in
+# the top-level namespace (e.g., ``norm=pplt.LogNorm(...)`` is allowed). To
+# explicitly set the normalization range, you can pass the usual `vmin` and `vmax`
+# keywords to the plotting command. See :ref:`below <ug_discrete>` for more
+# details on colormap normalization in proplot.
+
+# %%
+import proplot as pplt
+import numpy as np
+
 # Sample data
 N = 20
 state = np.random.RandomState(51423)
 data = 11 ** (0.25 * np.cumsum(state.rand(N, N), axis=0))
 
 # Create figure
-pplt.rc['cmap.diverging'] = 'IceFire'
-pplt.rc['cmap.sequential'] = 'magma'
-gs = pplt.GridSpec(ncols=2, nrows=2)
-fig = pplt.figure(refwidth=2.3, span=False)
+gs = pplt.GridSpec(ncols=2)
+fig = pplt.figure(refwidth=2.3, span=False, suptitle='Normalizer types')
 
 # Different normalizers
-ax = fig.subplot(gs[0, 0])
-ax.pcolormesh(data, colorbar='b')
-ax.format(title='Default normalizer')
-ax = fig.subplot(gs[0, 1])
-ax.pcolormesh(data, norm='log', colorbar='b')
-ax.format(title='Logarithmic normalizer')
+ax = fig.subplot(gs[0], title='Default linear normalizer')
+ax.pcolormesh(data, cmap='magma', colorbar='b')
+ax = fig.subplot(gs[1], title="Logarithmic normalizer with norm='log'")
+ax.pcolormesh(data, cmap='magma', norm='log', colorbar='b')
 
-# Different colormaps
-ax = fig.subplot(gs[1, 0])
-ax.pcolormesh(
-    np.log(data) - 4, colorbar='b',
-    diverging=True,  # use the default
-)
-ax.format(title='Default colormap')
-ax = fig.subplot(gs[1, 1])
-ax.pcolormesh(
-    np.log(data) - 4, colorbar='b',
-    cmap=('cobalt', 'white', 'violet red'),
-    cmap_kw={'space': 'hsl', 'cut': 0.15}
-)
-ax.format(title='On-the-fly colormap')
-
-# Format figure
-fig.format(xlabel='xlabel', ylabel='ylabel', grid=True)
-fig.format(suptitle='On-the-fly colormaps and normalizers')
-pplt.rc.reset()
-
-# %% [raw] raw_mimetype="text/restructuredtext"
-# .. _ug_discrete:
-#
-# Discrete color levels
-# ---------------------
-#
-# By default, proplot uses `~proplot.colors.DiscreteNorm` to "discretize"
-# the possible colormap colors for contour and pseudocolor plotting commands,
-# including `~proplot.axes.PlotAxes.contourf` and `~proplot.axes.PlotAxes.pcolor`.
-# This is analogous to `matplotlib.colors.BoundaryNorm`, except
-# `~proplot.colors.DiscreteNorm` can be paired with arbitrary
-# continuous normalizers like `~matplotlib.colors.LogNorm`,
-# `~proplot.colors.DivergingNorm`, or `~proplot.colors.SegmentedNorm`.
-# Discrete color levels can help readers discern exact numeric values and
-# tend to reveal qualitative structure in the data. `~proplot.colors.DiscreteNorm`
-# also repairs the colormap end-colors by ensuring the following conditions are met:
-#
-# #. All colormaps always span the *entire color range*,
-#    independent of the `extend` setting.
-# #. Cyclic colormaps always have *discrete color levels*
-#    on either end of the colorbar.
-#
-# To explicitly toggle discrete levels on or off, change :rcraw:`cmap.discrete`
-# or pass ``discrete=False`` or ``discrete=True`` to any plotting command
-# that accepts a `cmap` argument. The level edges or centers used with
-# `~proplot.colors.DiscreteNorm` can be explicitly specified using the `levels` and
-# `values` keywords (the `~proplot.utils.arange` and `~proplot.utils.edges` commands
-# are useful for generating level lists). You can also pass an integer to these
-# keywords (or to the `N` keyword) to automatically generate approximately that many
-# level edges or centers at "nice" intervals. The algorithm used to generate levels
-# is similar to matplotlib's algorithm for selecting contour levels. The default
-# number of levels is controlled by :rcraw:`cmap.levels`, and the algorithm is
-# constrained by the keywords `vmin`, `vmax`, `locator`, and `locator_kw` -- for
-# example, ``vmin=100`` ensures the minimum level is greater than or equal to ``100``,
-# and ``locator=5`` ensures a level step size of 5 (see the :ref:`axis locators
-# <ug_locators>` section for details). You can also use the keywords `positive`,
-# `negative`, and `symmetric` to ensure that your levels are strictly positive,
-# strictly negative, or symmetric about zero, or use the `nozero` keyword to remove
-# the zero level (useful for single-color `~proplot.axes.PlotAxes.contour` plots).
-
-# %%
-import proplot as pplt
-import numpy as np
-
-# Sample data
-state = np.random.RandomState(51423)
-data = 10 + (state.normal(0, 1, size=(33, 33))).cumsum(axis=0).cumsum(axis=1)
-
-# Figure
-fig, axs = pplt.subplots([[1, 1, 2, 2], [0, 3, 3, 0]], ref=3, refwidth=2.3)
-axs.format(yformatter='none', suptitle='Discrete vs. smooth colormap levels')
-
-# Pcolor
-axs[0].pcolor(data, cmap='spectral_r', norm='div', colorbar='l')
-axs[0].set_title('Pcolor plot\nDiscreteNorm enabled (default)')
-axs[1].pcolor(data, discrete=False, cmap='spectral_r', norm='div', colorbar='r')
-axs[1].set_title('Pcolor plot\nDiscreteNorm disabled')
-
-# Imshow
-data = 100 - data
-m = axs[2].imshow(data, cmap='thermal', colorbar='b')
-axs[2].format(title='Imshow plot\nDiscreteNorm disabled (default)', yformatter='auto')
-
-# %%
-import proplot as pplt
-import numpy as np
-
-# Sample data
-state = np.random.RandomState(51423)
-data = (20 * (state.rand(20, 20) - 0.4).cumsum(axis=0).cumsum(axis=1)) % 360
-levels = pplt.arange(0, 360, 45)
-
-# Figure
-gs = pplt.GridSpec(nrows=2, ncols=4, hratios=(1.5, 1))
-fig = pplt.figure(refwidth=2.4, right=2)
-fig.format(suptitle='DiscreteNorm end-color standardization')
-
-# Cyclic colorbar with distinct end colors
-ax = fig.subplot(gs[0, 1:3])
-ax.pcolormesh(
-    data, levels=levels, cmap='phase', extend='neither',
-    colorbar='b', colorbar_kw={'locator': 90}
-)
-ax.format(title='distinct "cyclic" end colors')
-
-# Colorbars with different extend values
-for i, extend in enumerate(('min', 'max', 'neither', 'both')):
-    ax = fig.subplot(gs[1, i])
-    ax.pcolormesh(
-        data[:, :10], levels=levels, cmap='oxy',
-        extend=extend, colorbar='b', colorbar_kw={'locator': 180}
-    )
-    ax.format(title=f'extend={extend!r}')
-
-# %% [raw] raw_mimetype="text/restructuredtext" tags=[]
-# .. _ug_autonorm:
-#
-# Auto normalization
-# ------------------
-#
-# By default, colormaps are normalized to span from roughly the minimum
-# data value to the maximum data value. However in the presence of outliers,
-# this is not desirable. Proplot adds the `robust` option to change this
-# behavior, inspired by the `xarray option
-# <http://xarray.pydata.org/en/stable/user-guide/plotting.html#robust>`__
-# of the same name. Passing ``robust=True`` to a `~proplot.axes.PlotAxes`
-# 2D plot command will limit the default colormap normalization between
-# the 2nd and 98th data percentiles. This range can be customized by passing
-# an integer to `robust` (e.g. ``robust=90`` limits the normalization range
-# between the 5th and 95th percentiles) or by passing a 2-tuple to `robust`
-# (e.g. ``robust=(0, 90)`` limits the normalization range between the
-# data minimum and the 90th percentile). This can be turned on persistently
-# by setting :rcraw:`cmap.robust` to ``True``.
-#
-# A related xarray feature is the `automatic detection
-# <http://xarray.pydata.org/en/stable/user-guide/plotting.html#colormaps>`__
-# of "diverging" datasets. Proplot automatically applies the default
-# diverging colormap :rc:`cmap.diverging` (rather than the default sequential
-# colormap :rc:`cmap.sequential`) along with the default continuous normalizer
-# `~proplot.colors.DivergingNorm` (see :ref:`below <ug_norm>`) if the
-# following conditions are met:
-#
-# #. The colormap was not passed, or the colormap was passed but its name
-#    matches the name of a :ref:`known diverging colormap <ug_cmaps_included>`.
-# #. If ``discrete=True`` (see :ref:`above <ug_discrete>`) and the discrete
-#    colormap levels include at least 2 positive values and 2 negative values.
-# #. If ``discrete=False`` (see :ref:`above <ug_discrete>`) and the normalization
-#    limits `vmin` and `vmax` have opposite signs.
-#
-# The automatic detection of diverging datasets can be disabled by
-# setting :rcraw:`cmap.autodiverging` to ``False``.
-
-# %%
-import proplot as pplt
-import numpy as np
-N = 20
-state = np.random.RandomState(51423)
-data = N * 2 + (state.rand(N, N) - 0.45).cumsum(axis=0).cumsum(axis=1) * 10
-fig, axs = pplt.subplots(nrows=2, ncols=2, refwidth=2)
-fig.format(suptitle='Auto normalization demo')
-
-# Auto diverging
-pplt.rc['cmap.sequential'] = 'lapaz_r'
-pplt.rc['cmap.diverging'] = 'vik'
-for i, ax in enumerate(axs[:2]):
-    ax.pcolor(data - i * N * 6, colorbar='b')
-    ax.format(title='Diverging ' + ('on' if i else 'off'))
-
-# Auto range
-pplt.rc['cmap.sequential'] = 'lajolla'
-data = data[::-1, :]
-data[-1, 0] = 2e3
-for i, ax in enumerate(axs[2:]):
-    ax.pcolor(data, robust=bool(i), colorbar='b')
-    ax.format(title='Robust ' + ('on' if i else 'off'))
-pplt.rc.reset()
 
 # %% [raw] raw_mimetype="text/restructuredtext"
 # .. _ug_norm:
@@ -460,20 +344,19 @@ pplt.rc.reset()
 # Special normalizers
 # -------------------
 #
-# Proplot includes a few new colormap normalizers. `~proplot.colors.SegmentedNorm`
-# provides even color gradations with respect to *index* for an arbitrary
-# monotonically increasing or decreasing list of levels. This is automatically
-# applied if you pass unevenly spaced `levels` to a plotting command, or it can be
-# manually applied using e.g. ``norm='segmented'``. This can be useful for datasets
-# with unusual statistical distributions or spanning a wide range of magnitudes.
+# Proplot includes two new :ref:`"continuous" normalizers <ug_norm>`.
+# `~proplot.colors.SegmentedNorm` provides even color gradations with respect to
+# index for an arbitrary monotonically increasing or decreasing list of levels. This is
+# automatically applied if you pass unevenly spaced `levels` to a plotting command, or
+# it can be manually applied using e.g. ``norm='segmented'``. This can be useful for
+# datasets with unusual statistical distributions or spanning many orders of magnitudes.
 #
-# The `~proplot.colors.DivergingNorm` normalizer ensures the colormap midpoint lies
-# on some *central* data value (usually 0), even if `vmin`, `vmax`, or `levels`
+# The `~proplot.colors.DivergingNorm` normalizer ensures that colormap midpoints lie
+# on some central data value (usually ``0``), even if `vmin`, `vmax`, or `levels`
 # are asymmetric with respect to the central value. This is automatically applied
-# if you don't explicitly specify an unknown or non-diverging colormap and your
-# data contains both negative and positive values, or it can be manually applied
-# using e.g. ``norm='diverging'``. It can also be configured to scale colors
-# "fairly" or "unfairly":
+# if your data contains negative and positive values (see :ref:`below <ug_autonorm>`),
+# or it can be manually applied using e.g. ``diverging=True`` or ``norm='diverging'``.
+# It can also be configured to scale colors "fairly" or "unfairly":
 #
 # * With fair scaling (the default), gradations on either side of the midpoint
 #   have equal intensity. If `vmin` and `vmax` are not symmetric about zero, the most
@@ -483,7 +366,7 @@ pplt.rc.reset()
 #   should be used with care, as it may lead you to misinterpret your data.
 #
 # The below examples demonstrate how these normalizers
-# affect the interpretation of colormap plots.
+# affect the interpretation of different datasets.
 
 # %%
 import proplot as pplt
@@ -532,6 +415,163 @@ for data, mode, fair in zip(
         ax.format(title=f'{mode.title()}-skewed + {fair} scaling')
         i += 1
 
+# %% [raw] raw_mimetype="text/restructuredtext"
+# .. _ug_discrete:
+#
+# Discrete levels
+# ---------------
+#
+# By default, proplot uses `~proplot.colors.DiscreteNorm` to "discretize"
+# the possible colormap colors for contour and pseudocolor plotting commands
+# (e.g., `~proplot.axes.PlotAxes.contourf`, `~proplot.axes.PlotAxes.pcolor`).
+# This is analogous to `matplotlib.colors.BoundaryNorm`, except
+# `~proplot.colors.DiscreteNorm` can be paired with arbitrary
+# continuous normalizers specified by `norm` (see :ref:`above <ug_norm>`).
+# Discrete color levels can help readers discern exact numeric values and
+# tend to reveal qualitative structure in the data. `~proplot.colors.DiscreteNorm`
+# also repairs the colormap end-colors by ensuring the following conditions are met:
+#
+# #. All colormaps always span the *entire color range*
+#    regardless of the `extend` parameter.
+# #. Cyclic colormaps always have *distinct color levels*
+#    on either end of the colorbar.
+#
+# To explicitly toggle discrete levels on or off, change :rcraw:`cmap.discrete`
+# or pass ``discrete=False`` or ``discrete=True`` to any plotting command
+# that accepts a `cmap` argument. The level edges or centers used with
+# `~proplot.colors.DiscreteNorm` can be explicitly specified using the `levels` and
+# `values` keywords (the `~proplot.utils.arange` and `~proplot.utils.edges` commands
+# are useful for generating level lists). You can also pass an integer to these
+# keywords (or to the `N` keyword) to automatically generate approximately that many
+# level edges or centers at "nice" intervals. The algorithm used to generate levels
+# is similar to matplotlib's algorithm for selecting contour levels. The default
+# number of levels is controlled by :rcraw:`cmap.levels`, and the level selection
+# is constrainted by the keywords `vmin`, `vmax`, `locator`, and `locator_kw` -- for
+# example, ``vmin=100`` ensures the minimum level is greater than or equal to ``100``,
+# and ``locator=5`` ensures a level step size of 5 (see :ref:`this section
+# <ug_locators>` for more on locators). You can also use the keywords `negative`,
+# `positive`, or `symmetric` to ensure that your levels are strictly negative,
+# positive, or symmetric about zero, or use the `nozero` keyword to remove
+# the zero level (useful for single-color `~proplot.axes.PlotAxes.contour` plots).
+
+# %%
+import proplot as pplt
+import numpy as np
+
+# Sample data
+state = np.random.RandomState(51423)
+data = 10 + (state.normal(0, 1, size=(33, 33))).cumsum(axis=0).cumsum(axis=1)
+
+# Figure
+fig, axs = pplt.subplots([[1, 1, 2, 2], [0, 3, 3, 0]], ref=3, refwidth=2.3)
+axs.format(yformatter='none', suptitle='Discrete vs. smooth colormap levels')
+
+# Pcolor
+axs[0].pcolor(data, cmap='oslo', norm='div', colorbar='l')
+axs[0].set_title('Pcolor plot\ndiscrete=True (default)')
+axs[1].pcolor(data, discrete=False, cmap='oslo', norm='div', colorbar='r')
+axs[1].set_title('Pcolor plot\ndiscrete=False')
+
+# Imshow
+data = 100 - data
+m = axs[2].imshow(data, cmap='viridis', colorbar='b')
+axs[2].format(title='Imshow plot\ndiscrete=False (default)', yformatter='auto')
+
+# %%
+import proplot as pplt
+import numpy as np
+
+# Sample data
+state = np.random.RandomState(51423)
+data = (20 * (state.rand(20, 20) - 0.4).cumsum(axis=0).cumsum(axis=1)) % 360
+levels = pplt.arange(0, 360, 45)
+
+# Figure
+gs = pplt.GridSpec(nrows=2, ncols=4, hratios=(1.5, 1))
+fig = pplt.figure(refwidth=2.4, right=2)
+fig.format(suptitle='DiscreteNorm end-color standardization')
+
+# Cyclic colorbar with distinct end colors
+cmap = pplt.Colormap('twilight', shift=-90)
+ax = fig.subplot(gs[0, 1:3], title='distinct "cyclic" end colors')
+ax.pcolormesh(
+    data, cmap=cmap, levels=levels,
+    colorbar='b', colorbar_kw={'locator': 90},
+)
+
+# Colorbars with different extend values
+for i, extend in enumerate(('min', 'max', 'neither', 'both')):
+    ax = fig.subplot(gs[1, i], title=f'extend={extend!r}')
+    ax.pcolormesh(
+        data[:, :10], levels=levels, cmap='oxy',
+        extend=extend, colorbar='b', colorbar_kw={'locator': 180}
+    )
+
+# %% [raw] raw_mimetype="text/restructuredtext" tags=[]
+# .. _ug_autonorm:
+#
+# Auto normalization
+# ------------------
+#
+# By default, colormaps are normalized to span from roughly the minimum
+# data value to the maximum data value. However in the presence of outliers,
+# this is not desirable. Proplot adds the `robust` keyword to change this
+# behavior, inspired by the `xarray keyword
+# <http://xarray.pydata.org/en/stable/user-guide/plotting.html#robust>`__
+# of the same name. Passing ``robust=True`` to a `~proplot.axes.PlotAxes`
+# 2D plot command will limit the default colormap normalization between
+# the 2nd and 98th data percentiles. This range can be customized by passing
+# an integer to `robust` (e.g. ``robust=90`` limits the normalization range
+# between the 5th and 95th percentiles) or by passing a 2-tuple to `robust`
+# (e.g. ``robust=(0, 90)`` limits the normalization range between the
+# data minimum and the 90th percentile). This can be turned on persistently
+# by setting :rcraw:`cmap.robust` to ``True``.
+#
+# Additionally, `similar to xarray
+# <http://xarray.pydata.org/en/stable/user-guide/plotting.html#colormaps>`__,
+# proplot can automatically detect "diverging" datasets. By default, the
+# `~proplot.axes.PlotAxes` 2D plot commands will apply the diverging colormap
+# :rc:`cmap.diverging` (rather than :rc:`cmap.sequential`) and the diverging
+# normalizer `~proplot.colors.DivergingNorm` (rather than `~matplotlib.colors.Normalize`
+# -- see :ref:`above <ug_norm>`) if the following conditions are met:
+#
+# #. If discrete levels are enabled (see :ref:`above <ug_discrete>`) and the
+#    level list includes at least 2 negative and 2 positive values.
+# #. If discrete levels are disabled (see :ref:`above <ug_discrete>`) and the
+#    normalization limits `vmin` and `vmax` are negative and positive.
+# #. A colormap was not explicitly passed, or a colormap was passed but it
+#    matches the name of a :ref:`known diverging colormap <ug_cmaps_included>`.
+#
+# The automatic detection of "diverging" datasets can be disabled by
+# setting :rcraw:`cmap.autodiverging` to ``False``.
+
+# %%
+import proplot as pplt
+import numpy as np
+N = 20
+state = np.random.RandomState(51423)
+data = N * 2 + (state.rand(N, N) - 0.45).cumsum(axis=0).cumsum(axis=1) * 10
+fig, axs = pplt.subplots(
+    nrows=2, ncols=2, refwidth=2,
+    suptitle='Auto normalization demo'
+)
+
+# Auto diverging
+pplt.rc['cmap.sequential'] = 'lapaz_r'
+pplt.rc['cmap.diverging'] = 'vik'
+for i, ax in enumerate(axs[:2]):
+    ax.pcolor(data - i * N * 6, colorbar='b')
+    ax.format(title='Diverging ' + ('on' if i else 'off'))
+
+# Auto range
+pplt.rc['cmap.sequential'] = 'lajolla'
+data = data[::-1, :]
+data[-1, 0] = 2e3
+for i, ax in enumerate(axs[2:]):
+    ax.pcolor(data, robust=bool(i), colorbar='b')
+    ax.format(title='Robust ' + ('on' if i else 'off'))
+pplt.rc.reset()
+
 # %% [raw] raw_mimetype="text/restructuredtext"
 # .. _ug_labels:
 #
