@@ -27,7 +27,14 @@ __all__ = [
 # Register projections with package prefix to avoid conflicts
 # NOTE: We integrate with cartopy and basemap rather than using matplotlib's
 # native projection system. Therefore axes names are not part of public API.
-for _cls in (CartesianAxes, PolarAxes, _BasemapAxes, _CartopyAxes, ThreeAxes):
+_cls_dict = {}  # track valid names
+for _cls in (CartesianAxes, PolarAxes, _CartopyAxes, _BasemapAxes, ThreeAxes):
     for _name in (_cls._name, *_cls._name_aliases):
         with context._state_context(_cls, name='proplot_' + _name):
             mproj.register_projection(_cls)
+            _cls_dict[_name] = _cls
+_cls_table = '\n'.join(
+    ' ' + key + ' ' * (max(map(len, _cls_dict)) - len(key) + 7)
+    + ('GeoAxes' if cls.__name__[:1] == '_' else cls.__name__)
+    for key, cls in _cls_dict.items()
+)
