@@ -14,7 +14,7 @@ from .. import scale as pscale
 from .. import ticker as pticker
 from ..config import rc
 from ..internals import ic  # noqa: F401
-from ..internals import _not_none, _pop_rc, dependencies, docstring, textmods, warnings
+from ..internals import _not_none, _pop_rc, dependencies, docstring, texts, warnings
 from . import plot, shared
 
 __all__ = ['CartesianAxes']
@@ -37,16 +37,13 @@ aspect : {'auto', 'equal'} or float, optional
 xlabel, ylabel : str, optional
     The x and y axis labels. Applied with `~matplotlib.axes.Axes.set_xlabel`
     and `~matplotlib.axes.Axes.set_ylabel`.
-xlabelpad, ylabelpad : unit-spec, optional
-    The padding between the x and y axis bounding box and the
-    x and y axis labels. Default is :rc:`label.pad`.
-    %(units.pt)s
 xlabel_kw, ylabel_kw : dict-like, optional
-    Additional settings used to update the axis labels with ``text.update()``.
+    Additional axis label settings applied with `~matplotlib.axes.Axes.set_xlabel`
+    and `~matplotlib.axes.Axes.set_ylabel`. See also `labelpad`, `labelcolor`,
+    `labelsize`, and `labelweight` below.
 xlim, ylim : 2-tuple of floats or None, optional
-    The x and y axis data limits. Applied with
-    `~matplotlib.axes.Axes.set_xlim` and
-    `~matplotlib.axes.Axes.set_ylim`.
+    The x and y axis data limits. Applied with `~matplotlib.axes.Axes.set_xlim`
+    and `~matplotlib.axes.Axes.set_ylim`.
 xmin, ymin : float, optional
     The x and y minimum data limits. Useful if you do not want
     to set the maximum limits.
@@ -62,6 +59,25 @@ xscale, yscale : scale-spec, optional
     ``xscale=('cutoff', 100, 2)`` applies a `~proplot.scale.CutoffScale`.
 xscale_kw, yscale_kw : dict-like, optional
     The x and y axis scale settings. Passed to `~proplot.scale.Scale`.
+xmargin, ymargin, margin : float, optional
+    The default margin between plotted content and the x and y axis spines in
+    axes-relative coordinates. Use this to add whitespace between plotted content and
+    axes edges without explicitly setting the limits. Use `margin` to set both at once.
+xbounds, ybounds : 2-tuple of float, optional
+    The x and y axis data bounds within which to draw the spines. For example,
+    ``xlim=(0, 4)`` combined with ``xbounds=(2, 4)`` will prevent the spines
+    from meeting at the origin. This also applies ``xspineloc='bottom'`` and
+    ``yspineloc='left'`` by default if both spines are currently visible.
+xtickrange, ytickrange : 2-tuple of float, optional
+    The x and y axis data ranges within which major tick marks are labelled.
+    For example, ``xlim=(-5, 5)`` combined with ``xtickrange=(-1, 1)`` and a
+    tick interval of 1 will only label the ticks marks at -1, 0, and 1. See
+    `~proplot.ticker.AutoFormatter` for details.
+xwraprange, ywraprange : 2-tuple of float, optional
+    The x and y axis data ranges with which major tick mark values are wrapped. For
+    example, ``xwraprange=(0, 3)`` causes the values 0 through 9 to be formatted as
+    0, 1, 2, 0, 1, 2, 0, 1, 2, 0. See `~proplot.ticker.AutoFormatter` for details. This
+    can be combined with `xtickrange` and `ytickrange` to make "stacked" line plots.
 xloc, yloc : optional
     Shorthands for `xspineloc`, `yspineloc`.
 xspineloc, yspineloc : {'bottom', 'top', 'left', 'right', \
@@ -86,12 +102,11 @@ xtickdir, ytickdir, tickdir : {'out', 'in', 'inout'}
     Direction that major and minor tick marks point for the x and y axis.
     Default is :rc:`tick.dir`. Use `tickdir` to control both.
 xticklabeldir, yticklabeldir : {'in', 'out'}
-    Whether to place x and y axis tick label text inside
-    or outside the axes.
-xticklabelpad, yticklabelpad : unit-spec, optional
-    The padding between the x and y axis ticks and
-    tick labels. Default is :rcraw:`tick.labelpad`.
-    %(units.pt)s
+    Whether to place x and y axis tick label text inside or outside the axes.
+    Propagates to `xtickdir` and `ytickdir` unless specified otherwise.
+xrotation, yrotation : float, optional
+    The rotation for x and y axis tick labels. Default is ``0``
+    for normal axes, :rc:`formatter.timerotation` for time x axes.
 xgrid, ygrid, grid : bool, optional
     Whether to draw major gridlines on the x and y axis.
     Use `grid` to toggle both.
@@ -125,29 +140,18 @@ xformatter, yformatter : formatter-spec, optional
     instance. Use ``[]``, ``'null'``, or ``'none'`` for no labels.
 xformatter_kw, yformatter_kw : dict-like, optional
     Keyword arguments passed to the `matplotlib.ticker.Formatter` class.
-xrotation, yrotation : float, optional
-    The rotation for x and y axis tick labels. Default is ``0``
-    for normal axes, :rc:`formatter.timerotation` for time x axes.
-xbounds, ybounds : 2-tuple of float, optional
-    The x and y axis data bounds within which to draw the spines.
-    For example, the axis range ``(0, 4)`` with bounds ``(1, 4)``
-    will prevent the spines from meeting at the origin.
-xtickrange, ytickrange : 2-tuple of float, optional
-    The x and y axis data ranges within which major tick marks
-    are labelled. For example, the tick range ``(-1, 1)`` with
-    axis range ``(-5, 5)`` and a tick interval of 1 will only
-    label the ticks marks at -1, 0, and 1. See
-    `~proplot.ticker.AutoFormatter` for details.
-xwraprange, ywraprange : 2-tuple of float, optional
-    The x and y axis data ranges with which major tick mark values are
-    wrapped. For example, the wrap range ``(0, 3)`` causes the values 0
-    through 9 to be formatted as 0, 1, 2, 0, 1, 2, 0, 1, 2, 0. See
-    `~proplot.ticker.AutoFormatter` for details.
-xmargin, ymargin, margin : float, optional
-    The default margin between plotted content and the x and y axis spines.
-    Value is proportional to the width, height of the axes. Use this to add
-    whitespace between plotted content and axes edges without explicitly
-    setting `xlim` or `ylim`. Use `margin` to set both at once.
+xcolor, ycolor, color : color-spec, optional
+    Color for the x and y axis spines, ticks, tick labels, and axis
+    labels. Use `color` to set both at once.
+xgridcolor, ygridcolor, gridcolor : color-spec, optional
+    Color for the x and y axis major and minor gridlines. Default is :rc:`grid.color`.
+    Use `gridcolor` to set both at once.
+xlinewidth, ylinewidth, linewidth : color-spec, optional
+    Line width for the x and y axis spines and major ticks. Propagates to
+    `tickwidth` unless specified otherwise. Use `linewidth` to set both at once.
+xtickcolor, ytickcolor, tickcolor : color-spec, optional
+    Color for the x and y axis ticks. Default is `xcolor`, `ycolor`, and `color` or
+    :rc:`tick.color` if they were not passed. Use `tickcolor` to set both at once.
 xticklen, yticklen, ticklen : unit-spec, optional
     Major tick lengths for the x and y axis. Default is :rc:`tick.len`.
     %(units.pt)s
@@ -156,10 +160,6 @@ xticklenratio, yticklenratio, ticklenratio : float, optional
     Relative scaling of `xticklen` and `yticklen` used to determine
     minor tick lengths. Default is :rc:`tick.lenratio`.
     Use `ticklenratio` to set both at once.
-xlinewidth, ylinewidth, linewidth : color-spec, optional
-    Line width for the x and y axis spines and major ticks.
-    Propagates to `tickwidth` unless specified otherwise.
-    Use `linewidth` to set both at once.
 xtickwidth, ytickwidth, tickwidth, : unit-spec, optional
     Major tick widths for the x ans y axis. Default is `linewidth`
     or :rc:`tick.width` if `linewidth` was not passed.
@@ -169,21 +169,34 @@ xtickwidthratio, ytickwidthratio, tickwidthratio
     Relative scaling of `xtickwidth` and `ytickwidth` used to determine
     minor tick widths. Default is :rc:`tick.widthratio`.
     Use `tickwidthratio` to set both at once.
-xcolor, ycolor, color : color-spec, optional
-    Color for the x and y axis spines, ticks, tick labels, and axis
-    labels. Use `color` to set both at once.
-xtickcolor, ytickcolor, tickcolor : color-spec, optional
-    Color for the x and y axis ticks. Inherits from `color` by
-    default. Use `tickcolor` to set both at once.
+xticklabelpad, yticklabelpad : unit-spec, optional
+    The padding between the x and y axis ticks and
+    tick labels. Default is :rcraw:`tick.labelpad`.
+    %(units.pt)s
 xticklabelcolor, yticklabelcolor, ticklabelcolor : color-spec, optional
-    Color for the x and y tick labels. Inherits from `color` by
-    default. Use `ticklabelcolor` to set both at once.
+    Color for the x and y tick labels. Default is `xcolor`, `ycolor`, and `color` or
+    :rc:`tick.labelcolor` if they were not passed. Use `ticklabelcolor` to set both.
+xticklabelsize, yticklabelsize, ticklabelsize : unit-spec or str, optional
+    Font size for the x and y tick labels. Default is :rc:`tick.labelsize`.
+    %(units.pt)s
+    Use `ticklabelsize` to set both at once.
+xticklabelweight, yticklabelweight, ticklabelweight : str, optional
+    Font weight for the x and y axis labels. Default is :rc:`label.weight`.
+    Use `ticklabelweight` to set both at once.
+xlabelpad, ylabelpad : unit-spec, optional
+    The padding between the x and y axis bounding box and
+    the x and y axis labels. Default is :rc:`label.pad`.
+    %(units.pt)s
 xlabelcolor, ylabelcolor, labelcolor : color-spec, optional
-    Color for the x and y axis labels. Inherits from `color` by
-    default. Use `labelcolor` to set both at once.
-xgridcolor, ygridcolor, gridcolor : color-spec, optional
-    Color for the x and y axis major and minor gridlines.
-    Use `gridcolor` to set both at once.
+    Color for the x and y axis labels. Default is `xcolor`, `ycolor`, and `color` or
+    :rc:`label.color` if they were not passed. Use `labelcolor` to set both at once.
+xlabelsize, ylabelsize, labelsize : unit-spec or str, optional
+    Font size for the x and y axis labels. Default is :rc:`label.size`.
+    %(units.pt)s
+    Use `labelsize` to set both at once.
+xlabelweight, ylabelweight, labelweight : str, optional
+    Font weight for the x and y axis labels. Default is :rc:`label.weight`.
+    Use `labelweight` to set both at once.
 fixticks : bool, optional
     Whether to always transform the tick locators to a
     `~matplotlib.ticker.FixedLocator` instance. Default is ``False``.
@@ -300,14 +313,14 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         """
         Parameters
         ----------
+        *args
+            Passed to `matplotlib.axes.Axes`.
         %(cartesian.format)s
-        *args, **kwargs
-            Passed to `proplot.axes.Axes`.
 
         Other parameters
         ----------------
         %(axes.format)s
-        %(axes.rc)s
+        %(rc.init)s
 
         See also
         --------
@@ -355,7 +368,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         if self._sharex is not None and axis.get_visible():
             level = 3 if self._panel_sharex_group else self.figure._sharex
             if level > 0:
-                textmods._transfer_text(axis.label, self._sharex.xaxis.label)
+                texts._transfer_text(axis.label, self._sharex.xaxis.label)
                 axis.label.set_visible(False)
             if level > 2:
                 # WARNING: Cannot set NullFormatter because shared axes share the
@@ -366,7 +379,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         if self._sharey is not None and axis.get_visible():
             level = 3 if self._panel_sharey_group else self.figure._sharey
             if level > 0:
-                textmods._transfer_text(axis.label, self._sharey.yaxis.label)
+                texts._transfer_text(axis.label, self._sharey.yaxis.label)
                 axis.label.set_visible(False)
             if level > 2:
                 axis.set_tick_params(which='both', labelleft=False, labelright=False)
@@ -423,6 +436,69 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         child.set_ylim(nlim, emit=False)
         child._dualy_prevstate = (scale, *olim)
 
+    def _fix_ticks(self, x, fixticks=False):
+        """
+        Ensure there are no out-of-bounds ticks. Mostly a brute-force version of
+        `~matplotlib.axis.Axis.set_smart_bounds` (which I couldn't get to work).
+        """
+        # NOTE: Previously triggered this every time FixedFormatter was found
+        # on axis but 1) that seems heavy-handed + strange and 2) internal
+        # application of FixedFormatter by boxplot resulted in subsequent format()
+        # successfully calling this and messing up the ticks for some reason.
+        # So avoid using this when possible, and try to make behavior consistent
+        # by cacheing the locators before we use them for ticks.
+        axis = getattr(self, f'{x}axis')
+        sides = ('bottom', 'top') if x == 'x' else ('left', 'right')
+        l0, l1 = getattr(self, f'get_{x}lim')()
+        bounds = tuple(self.spines[side].get_bounds() or (None, None) for side in sides)
+        skipticks = lambda xs: [  # noqa: E731
+            x for x in xs if not any(
+                x < _not_none(b0, l0) or x > _not_none(b1, l1) for (b0, b1) in bounds
+            )
+        ]
+        if fixticks or any(x is not None for b in bounds for x in b):
+            # Major locator
+            locator = getattr(axis, '_major_locator_cached', None)
+            if locator is None:
+                locator = axis._major_locator_cached = axis.get_major_locator()
+            locator = constructor.Locator(skipticks(locator()))
+            axis.set_major_locator(locator)
+            # Minor locator
+            locator = getattr(axis, '_minor_locator_cached', None)
+            if locator is None:
+                locator = axis._minor_locator_cached = axis.get_minor_locator()
+            locator = constructor.Locator(skipticks(locator()))
+            axis.set_minor_locator(locator)
+
+    def _get_spine_side(self, x, loc):
+        """
+        Get the spine side implied by the input location or position. This
+        propagates to tick mark, tick label, and axis label positions.
+        """
+        sides = ('bottom', 'top') if x == 'x' else ('left', 'right')
+        centers = ('zero', 'center')
+        options = (*sides, 'both', 'neither', 'none')
+        if np.iterable(loc) and len(loc) == 2 and loc[0] in ('axes', 'data', 'outward'):
+            lim = getattr(self, f'get_{x}lim')()
+            if loc[0] == 'outward':  # ambiguous so just choose first side
+                side = sides[0]
+            elif loc[0] == 'axes':
+                side = sides[int(loc[1] > 0.5)]
+            else:
+                side = sides[int(loc[1] > lim[0] + 0.5 * (lim[1] - lim[0]))]
+        elif loc in centers:  # ambiguous so just choose first side
+            side = sides[0]
+        elif loc is None or loc in options:
+            side = loc
+        else:
+            raise ValueError(
+                f'Invalid {x} spine location {loc!r}. Options are: '
+                + ', '.join(map(repr, (*options, *centers)))
+                + " or a coordinate position ('axes', coord), "
+                + " ('data', coord), or ('outward', coord)."
+            )
+        return side
+
     def _is_panel_group_member(self, other):
         """
         Return whether the axes belong in a panel sharing stack..
@@ -528,35 +604,6 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         if level > 1 and limits:
             self._sharey_limits(sharey)
 
-    def _update_bounds(self, x, fixticks=False):
-        """
-        Ensure there are no out-of-bounds labels. Mostly a brute-force version of
-        `~matplotlib.axis.Axis.set_smart_bounds` (which I couldn't get to work).
-        """
-        # NOTE: Previously triggered this every time FixedFormatter was found
-        # on axis but 1) that seems heavy-handed + strange and 2) internal
-        # application of FixedFormatter by boxplot resulted in subsequent format()
-        # successfully calling this and messing up the ticks for some reason.
-        # So avoid using this when possible, and try to make behavior consistent
-        # by cacheing the locators before we use them for ticks.
-        axis = getattr(self, x + 'axis')
-        sides = ('bottom', 'top') if x == 'x' else ('left', 'right')
-        bounds = tuple(self.spines[side].get_bounds() is not None for side in sides)
-        if fixticks or any(bounds) or axis.get_scale() == 'cutoff':
-            # Major locator
-            lim = bounds[0] or bounds[1] or getattr(self, 'get_' + x + 'lim')()
-            locator = getattr(axis, '_major_locator_cached', None)
-            if locator is None:
-                locator = axis._major_locator_cached = axis.get_major_locator()
-            locator = constructor.Locator([x for x in locator() if lim[0] <= x <= lim[1]])  # noqa: E501
-            axis.set_major_locator(locator)
-            # Minor locator
-            locator = getattr(axis, '_minor_locator_cached', None)
-            if locator is None:
-                locator = axis._minor_locator_cached = axis.get_minor_locator()
-            locator = constructor.Locator([x for x in locator() if lim[0] <= x <= lim[1]])  # noqa: E501
-            axis.set_minor_locator(locator)
-
     def _update_formatter(
         self, x, formatter=None, *, formatter_kw=None,
         tickrange=None, wraprange=None,
@@ -724,14 +771,17 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         """
         # Iterate over spines associated with this axis
         sides = ('bottom', 'top') if x == 'x' else ('left', 'right')
+        pside = self._get_spine_side(x, loc)  # side for set_position()
+        if bounds is not None and all(self.spines[s].get_visible() for s in sides):
+            loc = _not_none(loc, sides[0])
         for side in sides:
             # Change default spine location from 'both' to the first relevant
             # side if the user passes 'bounds'.
             spine = self.spines[side]
-            if loc is None and bounds is not None:
-                loc = _not_none(loc, sides[0])
             # Eliminate sides
-            if loc == 'neither':
+            if loc is None:
+                pass
+            elif loc == 'neither' or loc == 'none':
                 spine.set_visible(False)
             elif loc == 'both':
                 spine.set_visible(True)
@@ -740,18 +790,17 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             # Special spine location, usually 'zero', 'center', or tuple with
             # (units, location) where 'units' can be 'axes', 'data', or 'outward'.
             # Matplotlib internally represents these with 'bottom' and 'left'.
-            elif loc is not None:
-                if side == sides[1]:
-                    spine.set_visible(False)
-                else:
-                    spine.set_visible(True)
-                    try:
-                        spine.set_position(loc)
-                    except ValueError:
-                        raise ValueError(
-                            f'Invalid {x} spine location {loc!r}. Options are: '
-                            + ', '.join(map(repr, (*sides, 'both', 'neither'))) + '.'
-                        )
+            elif pside != side:
+                spine.set_visible(False)
+            else:
+                spine.set_visible(True)
+                try:
+                    spine.set_position(loc)
+                except ValueError:
+                    raise ValueError(
+                        f'Invalid {x} spine location {loc!r}. Options are: '
+                        + ', '.join(map(repr, (*sides, 'both', 'neither'))) + '.'
+                    )
             # Apply spine bounds
             if bounds is not None:
                 spine.set_bounds(*bounds)
@@ -835,25 +884,15 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         aspect=None,
         xloc=None, yloc=None,
         xspineloc=None, yspineloc=None,
-        xtickloc=None, ytickloc=None, fixticks=False,
-        xlabelloc=None, ylabelloc=None,
         xoffsetloc=None, yoffsetloc=None,
-        xticklabelloc=None, yticklabelloc=None,
-        xtickdir=None, ytickdir=None,
-        xgrid=None, ygrid=None,
-        xgridminor=None, ygridminor=None,
-        xtickminor=None, ytickminor=None,
-        xticklabeldir=None, yticklabeldir=None,
-        xticklabelpad=None, yticklabelpad=None,
-        xtickrange=None, ytickrange=None,
         xwraprange=None, ywraprange=None,
         xreverse=None, yreverse=None,
-        xlabel=None, ylabel=None,
-        xlabelpad=None, ylabelpad=None,
         xlim=None, ylim=None,
         xmin=None, ymin=None,
         xmax=None, ymax=None,
         xscale=None, yscale=None,
+        xbounds=None, ybounds=None,
+        xmargin=None, ymargin=None,
         xrotation=None, yrotation=None,
         xformatter=None, yformatter=None,
         xticklabels=None, yticklabels=None,
@@ -861,17 +900,31 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         xlocator=None, ylocator=None,
         xminorticks=None, yminorticks=None,
         xminorlocator=None, yminorlocator=None,
-        xbounds=None, ybounds=None,
-        xmargin=None, ymargin=None,
+        xcolor=None, ycolor=None,
+        xlinewidth=None, ylinewidth=None,
+        xtickloc=None, ytickloc=None, fixticks=False,
+        xtickdir=None, ytickdir=None,
+        xtickminor=None, ytickminor=None,
+        xtickrange=None, ytickrange=None,
+        xtickcolor=None, ytickcolor=None,
         xticklen=None, yticklen=None,
         xticklenratio=None, yticklenratio=None,
         xtickwidth=None, ytickwidth=None,
         xtickwidthratio=None, ytickwidthratio=None,
-        xlinewidth=None, ylinewidth=None,
-        xcolor=None, ycolor=None, color=None,  # special case (see below)
-        xtickcolor=None, ytickcolor=None,
+        xticklabelloc=None, yticklabelloc=None,
+        xticklabeldir=None, yticklabeldir=None,
+        xticklabelpad=None, yticklabelpad=None,
         xticklabelcolor=None, yticklabelcolor=None,
+        xticklabelsize=None, yticklabelsize=None,
+        xticklabelweight=None, yticklabelweight=None,
+        xlabel=None, ylabel=None,
+        xlabelloc=None, ylabelloc=None,
+        xlabelpad=None, ylabelpad=None,
         xlabelcolor=None, ylabelcolor=None,
+        xlabelsize=None, ylabelsize=None,
+        xlabelweight=None, ylabelweight=None,
+        xgrid=None, ygrid=None,
+        xgridminor=None, ygridminor=None,
         xgridcolor=None, ygridcolor=None,
         xlabel_kw=None, ylabel_kw=None,
         xscale_kw=None, yscale_kw=None,
@@ -892,7 +945,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         ----------------
         %(axes.format)s
         %(figure.format)s
-        %(axes.rc)s
+        %(rc.format)s
 
         See also
         --------
@@ -923,6 +976,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             yminorlocator_kw = yminorlocator_kw or {}
 
             # Color keyword arguments. Inherit from 'color' when necessary
+            color = kwargs.pop('color', None)
             xcolor = _not_none(xcolor, color)
             ycolor = _not_none(ycolor, color)
             if 'tick.color' not in rc_kw:
@@ -936,6 +990,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
                 ylabelcolor = _not_none(ylabelcolor, ycolor)
 
             # Flexible keyword args, declare defaults
+            # NOTE: 'xtickdir' and 'ytickdir' read from 'tickdir' arguments here
             xmargin = _not_none(xmargin, rc.find('axes.xmargin', context=True))
             ymargin = _not_none(ymargin, rc.find('axes.ymargin', context=True))
             xtickdir = _not_none(xtickdir, rc.find('xtick.direction', context=True))
@@ -948,16 +1003,23 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             ytickminor = _not_none(ytickminor, rc.find('ytick.minor.visible', context=True))  # noqa: E501
             xminorlocator = _not_none(xminorlocator=xminorlocator, xminorticks=xminorticks)  # noqa: E501
             yminorlocator = _not_none(yminorlocator=yminorlocator, yminorticks=yminorticks)  # noqa: E501
+            ticklabeldir = kwargs.pop('ticklabeldir', None)
+            xticklabeldir = _not_none(xticklabeldir, ticklabeldir)
+            yticklabeldir = _not_none(yticklabeldir, ticklabeldir)
+            xtickdir = _not_none(xtickdir, xticklabeldir)
+            ytickdir = _not_none(ytickdir, yticklabeldir)
 
             # Sensible defaults for spine, tick, tick label, and label locs
             # NOTE: Allow tick labels to be present without ticks! User may
             # want this sometimes! Same goes for spines!
             xspineloc = _not_none(xloc=xloc, xspineloc=xspineloc)
             yspineloc = _not_none(yloc=yloc, yspineloc=yspineloc)
-            if isinstance(xspineloc, str) and xspineloc not in ('zero', 'center'):
-                xtickloc = _not_none(xtickloc, xspineloc)
-            if isinstance(yspineloc, str) and yspineloc not in ('zero', 'center'):
-                ytickloc = _not_none(ytickloc, yspineloc)
+            xside = self._get_spine_side('x', xspineloc)
+            yside = self._get_spine_side('y', yspineloc)
+            if xside is not None and xside not in ('zero', 'center', 'both'):
+                xtickloc = _not_none(xtickloc, xside)
+            if yside is not None and yside not in ('zero', 'center', 'both'):
+                ytickloc = _not_none(ytickloc, yside)
             if xtickloc != 'both':  # then infer others
                 xticklabelloc = _not_none(xticklabelloc, xtickloc)
                 if xticklabelloc in ('bottom', 'top'):
@@ -975,52 +1037,99 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
 
             # Loop over axes
             for (
-                x, label,
-                labelpad, ticklabelpad,
-                color, linewidth,
-                gridcolor, labelcolor,
-                tickcolor, ticklabelcolor,
-                ticklen, ticklenratio,
-                tickwidth, tickwidthratio,
-                margin, bounds,
-                tickloc, spineloc,
-                ticklabelloc, labelloc,
-                offsetloc,
-                grid, gridminor,
-                tickminor, minorlocator,
-                min_, max_, lim,
-                reverse, scale,
-                locator, tickrange,
+                x,
+                min_,
+                max_,
+                lim,
+                reverse,
+                margin,
+                bounds,
+                tickrange,
                 wraprange,
-                formatter, tickdir,
-                ticklabeldir, rotation,
-                label_kw, scale_kw,
-                locator_kw, minorlocator_kw,
-                formatter_kw
+                scale,
+                scale_kw,
+                spineloc,
+                tickloc,
+                ticklabelloc,
+                labelloc,
+                offsetloc,
+                grid,
+                gridminor,
+                locator,
+                locator_kw,
+                minorlocator,
+                minorlocator_kw,
+                formatter,
+                formatter_kw,
+                label,
+                label_kw,
+                color,
+                gridcolor,
+                linewidth,
+                rotation,
+                tickminor,
+                tickdir,
+                tickcolor,
+                ticklen,
+                ticklenratio,
+                tickwidth,
+                tickwidthratio,
+                ticklabeldir,
+                ticklabelpad,
+                ticklabelcolor,
+                ticklabelsize,
+                ticklabelweight,
+                labelpad,
+                labelcolor,
+                labelsize,
+                labelweight,
             ) in zip(
-                ('x', 'y'), (xlabel, ylabel),
-                (xlabelpad, ylabelpad), (xticklabelpad, yticklabelpad),
-                (xcolor, ycolor), (xlinewidth, ylinewidth),
-                (xgridcolor, ygridcolor), (xlabelcolor, ylabelcolor),
-                (xtickcolor, ytickcolor), (xticklabelcolor, yticklabelcolor),
-                (xticklen, yticklen), (xticklenratio, yticklenratio),
-                (xtickwidth, ytickwidth), (xtickwidthratio, ytickwidthratio),
-                (xmargin, ymargin), (xbounds, ybounds),
-                (xtickloc, ytickloc), (xspineloc, yspineloc),
-                (xticklabelloc, yticklabelloc), (xlabelloc, ylabelloc),
-                (xoffsetloc, yoffsetloc),
-                (xgrid, ygrid), (xgridminor, ygridminor),
-                (xtickminor, ytickminor), (xminorlocator, yminorlocator),
-                (xmin, ymin), (xmax, ymax), (xlim, ylim),
-                (xreverse, yreverse), (xscale, yscale),
-                (xlocator, ylocator), (xtickrange, ytickrange),
+                ('x', 'y'),
+                (xmin, ymin),
+                (xmax, ymax),
+                (xlim, ylim),
+                (xreverse, yreverse),
+                (xmargin, ymargin),
+                (xbounds, ybounds),
+                (xtickrange, ytickrange),
                 (xwraprange, ywraprange),
-                (xformatter, yformatter), (xtickdir, ytickdir),
-                (xticklabeldir, yticklabeldir), (xrotation, yrotation),
-                (xlabel_kw, ylabel_kw), (xscale_kw, yscale_kw),
+                (xscale, yscale),
+                (xscale_kw, yscale_kw),
+                (xspineloc, yspineloc),
+                (xtickloc, ytickloc),
+                (xticklabelloc, yticklabelloc),
+                (xlabelloc, ylabelloc),
+                (xoffsetloc, yoffsetloc),
+                (xgrid, ygrid),
+                (xgridminor, ygridminor),
+                (xlocator, ylocator),
                 (xlocator_kw, ylocator_kw),
+                (xminorlocator, yminorlocator),
                 (xminorlocator_kw, yminorlocator_kw),
+                (xformatter, yformatter),
                 (xformatter_kw, yformatter_kw),
+                (xlabel, ylabel),
+                (xlabel_kw, ylabel_kw),
+                (xcolor, ycolor),
+                (xgridcolor, ygridcolor),
+                (xlinewidth, ylinewidth),
+                (xrotation, yrotation),
+                (xtickminor, ytickminor),
+                (xtickdir, ytickdir),
+                (xtickcolor, ytickcolor),
+                (xticklen, yticklen),
+                (xticklenratio, yticklenratio),
+                (xtickwidth, ytickwidth),
+                (xtickwidthratio, ytickwidthratio),
+                (xticklabeldir, yticklabeldir),
+                (xticklabelpad, yticklabelpad),
+                (xticklabelcolor, yticklabelcolor),
+                (xticklabelsize, yticklabelsize),
+                (xticklabelweight, yticklabelweight),
+                (xlabelpad, ylabelpad),
+                (xlabelcolor, ylabelcolor),
+                (xlabelsize, ylabelsize),
+                (xlabelweight, ylabelweight),
             ):
                 # Axis scale
                 # WARNING: This relies on monkey patch of mscale.scale_factory
@@ -1063,14 +1172,20 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
                     ticklen=ticklen, ticklenratio=ticklenratio,
                     tickdir=tickdir, labeldir=ticklabeldir, labelpad=ticklabelpad,
                     tickcolor=tickcolor, gridcolor=gridcolor, labelcolor=ticklabelcolor,
+                    labelsize=ticklabelsize, labelweight=ticklabelweight,
                 )
 
                 # Axis label settings
-                # NOTE: This must come after set_label_position, or ha or va overrides
-                # in label_kw are overwritten.
-                self._update_labels(
-                    x, label, color=labelcolor, labelpad=labelpad, **label_kw
+                # NOTE: This must come after set_label_position, or any ha and va
+                # overrides in label_kw are overwritten.
+                kw = dict(
+                    labelpad=labelpad,
+                    color=labelcolor,
+                    size=labelsize,
+                    weight=labelweight,
+                    **label_kw
                 )
+                self._update_labels(x, label, **kw)
 
                 # Axis locator
                 if minorlocator is True or minorlocator is False:  # must test identity
@@ -1093,7 +1208,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
                 )
 
                 # Ensure ticks are within axis bounds
-                self._update_bounds(x, fixticks=fixticks)
+                self._fix_ticks(x, fixticks=fixticks)
 
         # Parent format method
         if aspect is not None:
@@ -1104,8 +1219,9 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         """
         Optionally omit the leading x or y from "twin axes" methods.
         """
-        keys = tuple(k[1:] for k in self._format_signature.parameters if k[0] == x)
-        kwargs = {(x + k if k in keys else k): v for k, v in kwargs.items()}
+        sig = self._format_signatures[CartesianAxes]
+        keys = tuple(key[1:] for key in sig.parameters if key[0] == x)
+        kwargs = {(x + key if key in keys else key): val for key, val in kwargs.items()}
         for axis in 'xy':  # standardize format() location aliases
             if axis + 'spineloc' in kwargs:
                 kwargs[axis + 'loc'] = kwargs.pop(axis + 'spineloc')
@@ -1200,18 +1316,18 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         return ax
 
     @docstring._snippet_manager
-    def twinx(self):
+    def twinx(self, **kwargs):
         """
         %(axes.twinx)s
         """
-        return self.alty()
+        return self.alty(**kwargs)
 
     @docstring._snippet_manager
-    def twiny(self):
+    def twiny(self, **kwargs):
         """
         %(axes.twiny)s
         """
-        return self.altx()
+        return self.altx(**kwargs)
 
     def draw(self, renderer=None, *args, **kwargs):
         # Perform extra post-processing steps
@@ -1232,7 +1348,8 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         self._update_rotation('x')
         return super().get_tightbbox(renderer, *args, **kwargs)
 
-    # Apply signature obfuscation after getting keys
-    # NOTE: This is needed for __init__, altx, and alty
-    _format_signature = inspect.signature(format)
-    format = docstring._obfuscate_kwargs(format)
+
+# Apply signature obfuscation after storing previous signature
+# NOTE: This is needed for __init__, altx, and alty
+CartesianAxes._format_signatures[CartesianAxes] = inspect.signature(CartesianAxes.format)  # noqa: E501
+CartesianAxes.format = docstring._obfuscate_kwargs(CartesianAxes.format)
