@@ -88,6 +88,7 @@ latmax : float, optional
     Default is ``80``.
 labels : bool, optional
     Sets `lonlabels` and `latlabels` to ``True``. Default is :rc:`grid.labels`.
+    To draw labels by default use e.g. ``pplt.rc['grid.labels'] = True``.
 lonlabels, latlabels : optional
     Whether to label longitudes and latitudes, and on which sides
     of the map. There are four different options:
@@ -124,12 +125,13 @@ lonformatter_kw, latformatter_kw : dict-like, optional
     Keyword arguments passed to the `matplotlib.ticker.Formatter` class.
 loninline, latinline, inlinelabels : bool, optional
     *For cartopy axes only.*
-    Whether to draw inline longitude and latitude gridline labels.
-    Default is :rc:`grid.inlinelabels`.
+    Whether to draw inline longitude and latitude gridline labels. Default is
+    :rc:`grid.inlinelabels`. Setting these to ``True`` also sets the default
+    values for `lonlabels`, `latlabels`, and `labels` to ``True`` (respectively).
 rotatelabels : bool, optional
     *For cartopy axes only.*
-    Whether to rotate longitude and latitude gridline labels.
-    Default is :rc:`grid.rotatelabels`.
+    Whether to rotate longitude and latitude gridline
+    labels. Default is :rc:`grid.rotatelabels`.
 labelpad : unit-spec, optional
     *For cartopy axes only.*
     The padding between the map boundary and longitude and
@@ -162,10 +164,16 @@ reso : {'lo', 'med', 'hi', 'x-hi', 'xx-hi'}, optional
     The resolution of geographic features. For basemap axes, this must
     be passed to `~proplot.constructor.Proj`.
 color : color-spec, optional
-    Color for the axes edge. Propagates to `gridlabelcolor` unless
+    Color for the axes edge. Propagates to `labelcolor` unless
     specified otherwise (similar to `proplot.axes.CartesianAxes.format`).
-gridlabelcolor : color-spec, optional
-    Color for the grid labels. Inherits from `color` by default.
+labelcolor, gridlabelcolor : color-spec, optional
+    Color for the grid labels. Default is `color` or :rc:`grid.labelcolor`
+    if `color` was not passed.
+labelsize, gridlabelsize : unit-spec or str, optional
+    Font size for the gridline labels. Default is :rc:`grid.labelsize`.
+    %(units.pt)s
+labelweight, gridlabelweight : str, optional
+    Font weight for the gridline labels. Default is :rc:`grid.labelweight`.
 """
 docstring._snippet_manager['geo.format'] = _format_docstring
 
@@ -386,31 +394,40 @@ class GeoAxes(plot.PlotAxes):
     `~proplot.figure.Figure.add_subplot`, and `~proplot.figure.Figure.subplots`,
     where ``proj_name`` is a registered :ref:`PROJ projection name <proj_table>`.
     You can also pass a `cartopy.crs.Projection` or `~mpl_toolkits.basemap.Basemap`
-    instance instead of a projection name.
+    instance instead of a projection name. Alternatively, you can pass any of the
+    matplotlib-recognized axes subclass names ``proj='cartopy'``, ``proj='geo'``, or
+    ``proj='geographic'`` with a `cartopy.crs.Projection` `map_projection` keyword
+    argument, or pass ``proj='basemap'`` with a `~mpl_toolkits.basemap.Basemap`
+    `map_projection` keyword argument.
     """
     @docstring._snippet_manager
     def __init__(self, *args, **kwargs):
         """
         Parameters
         ----------
+        *args
+            Passed to `matplotlib.axes.Axes`.
         autoextent : bool, optional
             *For cartopy axes only*. Whether to automatically adjust map bounds
-            based on plotted content or enforce global map extent. Default is
-            :rc:`cartopy.autoextent`.
+            based on plotted content or enforce a global map extent (or a map bounded
+            at the equator for polar projections). The extent can subsequently by
+            adjusted with the `~GeoAxes.format` keywords `lonlim`, `latlim`, and
+            `boundinglat`, or with `~cartopy.mpl.geoaxes.GeoAxes.set_extent`.
+            Default is :rc:`cartopy.autoextent`.
         circular : bool, optional
             *For cartopy axes only*. Whether to bound polar projections with circles
-            rather than squares. Default is :rc:`cartopy.circular`.
-        map_projection : `~mpl_toolkits.basemap.Basemap` or `~cartopy.crs.Projection`
-            The cartopy or basemap projection instance. This is passed automatically
-            when calling commands like `~proplot.figure.Figure.add_subplot`.
+            rather than squares. Note that outer gridline labels cannot be added to
+            circularly bounded polar projections. Default is :rc:`cartopy.circular`.
+        map_projection : `~cartopy.crs.Projection` or `~mpl_toolkits.basemap.Basemap`
+            The cartopy or basemap projection instance. This is
+            passed automatically when calling axes-creation
+            commands like `~proplot.figure.Figure.add_subplot`.
         %(geo.format)s
-        *args, **kwargs
-            Passed to `proplot.axes.Axes`.
 
         Other parameters
         ----------------
         %(axes.format)s
-        %(axes.rc)s
+        %(rc.init)s
 
         Note
         ----
@@ -524,7 +541,8 @@ class GeoAxes(plot.PlotAxes):
         lonformatter_kw=None, latformatter_kw=None,
         labels=None, latlabels=None, lonlabels=None,
         loninline=None, latinline=None, inlinelabels=None, rotatelabels=None,
-        labelpad=None, dms=None, nsteps=None,
+        labelpad=None, labelcolor=None, labelsize=None, labelweight=None,
+        dms=None, nsteps=None,
         **kwargs,
     ):
         """
@@ -539,7 +557,7 @@ class GeoAxes(plot.PlotAxes):
         ----------------
         %(axes.format)s
         %(figure.format)s
-        %(axes.rc)s
+        %(rc.format)s
 
         See also
         --------
@@ -562,17 +580,22 @@ class GeoAxes(plot.PlotAxes):
 
         # Initiate context block
         rc_kw, rc_mode = _pop_rc(kwargs)
-        if 'color' in kwargs and 'grid.labelcolor' not in rc_kw:
-            rc_kw['grid.labelcolor'] = kwargs['color']
+        labelcolor = _not_none(labelcolor, kwargs.get('color', None))
+        if labelcolor is not None:
+            rc_kw['grid.labelcolor'] = labelcolor
+        if labelsize is not None:
+            rc_kw['grid.labelsize'] = labelsize
+        if labelweight is not None:
+            rc_kw['grid.labelweight'] = labelweight
         with rc.context(rc_kw, mode=rc_mode):
             # Label toggles
             labels = _not_none(labels, rc.find('grid.labels', context=True))
-            lonlabels = _not_none(lonlabels, labels)
-            latlabels = _not_none(latlabels, labels)
+            lonlabels = _not_none(lonlabels, labels, loninline, inlinelabels)
+            latlabels = _not_none(latlabels, labels, latinline, inlinelabels)
             lonarray = self._to_label_array(lonlabels, lon=True)
             latarray = self._to_label_array(latlabels, lon=False)
 
-            # Update 'maximum latitude'
+            # Update max latitude
             latmax = _not_none(latmax, rc.find('grid.latmax', context=True))
             if latmax is not None:
                 self._lataxis.set_latmax(latmax)
@@ -669,11 +692,6 @@ class GeoAxes(plot.PlotAxes):
             raise ValueError(f'Projection must be a {cls} instance.')
         self._map_projection = map_projection
 
-    # Apply signature obfuscation after getting keys
-    # NOTE: This is needed for __init__
-    _format_signature = inspect.signature(format)
-    format = docstring._obfuscate_kwargs(format)
-
 
 class _CartopyAxes(GeoAxes, _GeoAxes):
     """
@@ -1006,9 +1024,9 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
         Update major gridlines.
         """
         # Update gridline locations and style
-        if self._gridlines_major is None:
-            self._gridlines_major = self._init_gridlines()
         gl = self._gridlines_major
+        if gl is None:
+            gl = self._gridlines_major = self._init_gridlines()
         self._update_gridlines(
             gl, which='major', longrid=longrid, latgrid=latgrid, nsteps=nsteps,
         )
@@ -1021,11 +1039,11 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
         if labelpad is not None:
             gl.xpadding = gl.ypadding = labelpad
         if loninline is not None:
-            gl.x_inline = loninline
+            gl.x_inline = bool(loninline)
         if latinline is not None:
-            gl.y_inline = latinline
+            gl.y_inline = bool(latinline)
         if rotatelabels is not None:
-            gl.rotate_labels = rotatelabels  # ignored in cartopy <0.18
+            gl.rotate_labels = bool(rotatelabels)  # ignored in cartopy <0.18
 
         # Gridline label formatters
         lonaxis = self._lonaxis
@@ -1057,9 +1075,9 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
         """
         Update minor gridlines.
         """
-        if self._gridlines_minor is None:
-            self._gridlines_minor = self._init_gridlines()
         gl = self._gridlines_minor
+        if gl is None:
+            gl = self._gridlines_minor = self._init_gridlines()
         self._update_gridlines(
             gl, which='minor', longrid=longrid, latgrid=latgrid, nsteps=nsteps,
         )
@@ -1126,8 +1144,10 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
         if isinstance(crs, ccrs.PlateCarree):
             self._set_view_intervals(extent)
             with rc.context(mode=2):  # do not reset gridline properties!
-                self._update_gridlines(self._gridlines_major, which='major')
-                self._update_gridlines(self._gridlines_minor, which='minor')
+                if self._gridlines_major is not None:
+                    self._update_gridlines(self._gridlines_major, which='major')
+                if self._gridlines_minor is not None:
+                    self._update_gridlines(self._gridlines_minor, which='minor')
             if dependencies._version_cartopy < 0.18:
                 clipped_path = self.outline_patch.orig_path.clip_to_bbox(self.viewLim)
                 self.outline_patch._path = clipped_path
@@ -1395,3 +1415,8 @@ class _BasemapAxes(GeoAxes):
             axis.isDefault_majfmt = True
             axis.isDefault_majloc = True
             axis.isDefault_minloc = True
+
+
+# Apply signature obfuscation after storing previous signature
+GeoAxes._format_signatures[GeoAxes] = inspect.signature(GeoAxes.format)
+GeoAxes.format = docstring._obfuscate_kwargs(GeoAxes.format)
