@@ -16,11 +16,13 @@ class ThreeAxes(shared._SharedAxes, base.Axes, Axes3D):
 
     Important
     ---------
-    This axes subclass does not implement the `~proplot.axes.PlotAxes` plotting
-    overrides. It can be used by passing ``proj='3d'`` or ``proj='three'``
-    to axes-creation commands like `~proplot.figure.Figure.add_axes`,
+    Note that this subclass does *not* implement the `~proplot.axes.PlotAxes`
+    plotting overrides. This axes subclass can be used by passing ``proj='3d'`` or
+    ``proj='three'`` to axes-creation commands like `~proplot.figure.Figure.add_axes`,
     `~proplot.figure.Figure.add_subplot`, and `~proplot.figure.Figure.subplots`.
     """
+    # TODO: Figure out a way to have internal Axes3D calls to plotting commands
+    # access the overrides rather than the originals? May be impossible.
     _name = 'three'
     _name_aliases = ('3d',)
 
