@@ -39,9 +39,9 @@ except ImportError:
 try:
     import cartopy.crs as ccrs
     import cartopy.mpl.ticker as cticker
-    from cartopy.crs import CRS
+    from cartopy.crs import Projection
 except ModuleNotFoundError:
-    CRS = ccrs = cticker = object
+    Projection = ccrs = cticker = object
 
 __all__ = [
     'Proj',
@@ -293,6 +293,13 @@ else:
             + ', '.join(map(repr, PROJS_MISSING))
             + ' . Please consider updating cartopy.'
         )
+    PROJS_TABLE = (
+        'The known cartopy projection classes are:\n'
+        + '\n'.join(
+            ' ' + key + ' ' * (max(map(len, PROJS)) - len(key) + 10) + cls.__name__
+            for key, cls in PROJS.items()
+        )
+    )
 
 # Geographic feature properties
 FEATURES_CARTOPY = {  # positional arguments passed to NaturalEarthFeature
@@ -518,7 +525,7 @@ def Colormap(
 
     Returns
     -------
-    `~matplotlib.colors.Colormap`
+    matplotlib.colors.Colormap
         A `~proplot.colors.ContinuousColormap` or
         `~proplot.colors.DiscreteColormap` instance.
 
@@ -527,8 +534,8 @@ def Colormap(
     matplotlib.colors.Colormap
     matplotlib.colors.LinearSegmentedColormap
     matplotlib.colors.ListedColormap
-    Norm
-    Cycle
+    proplot.constructor.Norm
+    proplot.constructor.Cycle
     proplot.utils.get_colors
     """
     # Helper function
@@ -685,13 +692,12 @@ def Colormap(
 
     # Register the colormap
     if name is None:
-        name = cmap.name  # may have been modified by e.g. .shifted()
+        name = cmap.name  # may have been modified by e.g. reversed()
     else:
         cmap.name = name
     if not isinstance(name, str):
-        raise ValueError('Colormap name must be a string.')
-    if name and name[0] != '_':
-        pcolors._cmap_database[name] = cmap
+        raise ValueError('The colormap name must be a string.')
+    pcolors._cmap_database[name] = cmap
 
     # Save the colormap
     if save:
@@ -752,9 +758,10 @@ markeredgecolor, markerfacecolor : object or sequence of object, optional
         Lists of `~matplotlib.lines.Line2D` properties that can be added to the
         `~cycler.Cycler` instance. If the input was already a `~cycler.Cycler`,
         these are added or appended to the existing cycle keys. If the lists have
-        unequal length, they are repeated to their least common multiple (note
-        that matplotlib throws an error in this case). For more info on cyclers see
-        `~matplotlib.axes.Axes.set_prop_cycle`. Also see the `line style reference \
+        unequal length, they are repeated to their least common multiple (unlike
+        `~cycler.cycler`, which throws an error in this case). For more info
+        on cyclers see `~matplotlib.axes.Axes.set_prop_cycle`. Also see
+        the `line style reference \
 <https://matplotlib.org/2.2.5/gallery/lines_bars_and_markers/line_styles_reference.html>`__,
         the `marker reference \
 <https://matplotlib.org/stable/gallery/lines_bars_and_markers/marker_reference.html>`__,
@@ -770,15 +777,17 @@ markeredgecolors, markerfacecolors
 
     Returns
     -------
-    `~cycler.Cycler`
-        A cycler instance that can be passed to
-        `~matplotlib.axes.Axes.set_prop_cycle`.
+    cycler.Cycler
+        A `~cycler.Cycler` instance that can be passed
+        to `~matplotlib.axes.Axes.set_prop_cycle`.
 
     See also
     --------
+    cycler.cycler
     cycler.Cycler
-    Colormap
-    Norm
+    matplotlib.axes.Axes.set_prop_cycle
+    proplot.constructor.Colormap
+    proplot.constructor.Norm
     proplot.utils.get_colors
     """
     # Parse keyword arguments that rotate through other properties
@@ -877,17 +886,17 @@ def Norm(norm, *args, **kwargs):
 
     Returns
     -------
-    `~matplotlib.colors.Normalize`
+    matplotlib.colors.Normalize
         A `~matplotlib.colors.Normalize` instance.
 
     See also
     --------
     matplotlib.colors.Normalize
     proplot.colors.DiscreteNorm
-    Colormap
+    proplot.constructor.Colormap
     """
     if np.iterable(norm) and not isinstance(norm, str):
-        norm, args = norm[0], (*norm[1:], *args)
+        norm, *args = *norm, *args
     if isinstance(norm, mcolors.Normalize):
         return norm
     if not isinstance(norm, str):
@@ -969,7 +978,7 @@ def Locator(locator, *args, **kwargs):
 
     Returns
     -------
-    `~matplotlib.ticker.Locator`
+    matplotlib.ticker.Locator
         A `~matplotlib.ticker.Locator` instance.
 
     See also
@@ -979,12 +988,12 @@ def Locator(locator, *args, **kwargs):
     proplot.axes.PolarAxes.format
     proplot.axes.GeoAxes.format
     proplot.axes.Axes.colorbar
-    Formatter
+    proplot.constructor.Formatter
     """  # noqa: E501
     if np.iterable(locator) and not isinstance(locator, str) and not all(
         isinstance(num, Number) for num in locator
     ):
-        locator, args = locator[0], (*locator[1:], *args)
+        locator, *args = *locator, *args
     if isinstance(locator, mticker.Locator):
         return locator
     if isinstance(locator, str):
@@ -1034,12 +1043,12 @@ def Formatter(formatter, *args, date=False, index=False, **kwargs):
         * If a string containing ``{x}`` or ``{x:...}``, ticks will be
           formatted by calling ``string.format(x=number)``. Returns
           a `~matplotlib.ticker.StrMethodFormatter`.
-        * If a string containing ``'%'`` and `date` is ``False``, ticks will be
-          formatted using the C-style ``string % number`` method. See
+        * If a string containing ``'%'`` and `date` is ``False``, ticks
+          will be formatted using the C-style ``string % number`` method. See
           `this page <https://docs.python.org/3/library/stdtypes.html#printf-style-string-formatting>`__
           for a review. Returns a `~matplotlib.ticker.FormatStrFormatter`.
-        * If a string containing ``'%'`` and `date` is ``True``, *datetime*
-          `string % number`` formatting is used. See
+        * If a string containing ``'%'`` and `date` is ``True``, ticks
+          will be formatted using `~datetime.datetime.strfrtime`. See
           `this page <https://docs.python.org/3/library/datetime.html#strftime-and-strptime-format-codes>`__
           for a review. Returns a `~matplotlib.dates.DateFormatter`.
 
@@ -1091,6 +1100,7 @@ def Formatter(formatter, *args, date=False, index=False, **kwargs):
         ``'dmslat'``            `~proplot.ticker.LatitudeFormatter`             Latitude labels with degree/minute/second support
         ======================  ==============================================  =================================================================
 
+
     date : bool, optional
         Toggles the behavior when `formatter` contains a ``'%'`` sign
         (see above).
@@ -1105,7 +1115,7 @@ def Formatter(formatter, *args, date=False, index=False, **kwargs):
 
     Returns
     -------
-    `~matplotlib.ticker.Formatter`
+    matplotlib.ticker.Formatter
         A `~matplotlib.ticker.Formatter` instance.
 
     See also
@@ -1115,12 +1125,12 @@ def Formatter(formatter, *args, date=False, index=False, **kwargs):
     proplot.axes.PolarAxes.format
     proplot.axes.GeoAxes.format
     proplot.axes.Axes.colorbar
-    Locator
+    proplot.constructor.Locator
     """  # noqa: E501
     if np.iterable(formatter) and not isinstance(formatter, str) and not all(
         isinstance(item, str) for item in formatter
     ):
-        formatter, args = formatter[0], (*formatter[1:], *args)
+        formatter, *args = *formatter, *args
     if isinstance(formatter, mticker.Formatter):
         return formatter
     if isinstance(formatter, str):
@@ -1200,12 +1210,13 @@ def Scale(scale, *args, **kwargs):
 
     Returns
     -------
-    `~matplotlib.scale.ScaleBase`
-        The scale instance.
+    matplotlib.scale.ScaleBase
+        A `~matplotlib.scale.ScaleBase` instance.
 
     See also
     --------
     matplotlib.scale.ScaleBase
+    proplot.scale.LinearScale
     proplot.axes.CartesianAxes.format
     proplot.axes.CartesianAxes.dualx
     proplot.axes.CartesianAxes.dualy
@@ -1215,7 +1226,7 @@ def Scale(scale, *args, **kwargs):
     # ScaleBase classes as arguments... but constructor functions cannot
     # do anything but return the class instance upon receiving one.
     if np.iterable(scale) and not isinstance(scale, str):
-        scale, args = scale[0], (*scale[1:], *args)
+        scale, *args = *scale, *args
     if isinstance(scale, mscale.ScaleBase):
         return scale
     if not isinstance(scale, str):
@@ -1335,8 +1346,8 @@ def Proj(name, basemap=None, **kwargs):
 
     Returns
     -------
-    proj : `~mpl_toolkits.basemap.Basemap` or `~cartopy.crs.Projection`
-        The projection instance.
+    proj : mpl_toolkits.basemap.Basemap or cartopy.crs.Projection
+        A `~mpl_toolkits.basemap.Basemap` or `~cartopy.crs.Projection` instance.
 
     See also
     --------
@@ -1391,35 +1402,35 @@ def Proj(name, basemap=None, **kwargs):
     .. _wintri: https://proj4.org/operations/projections/wintri.html
     """  # noqa: E501
     # Class instances
-    use_basemap = _not_none(basemap, rc['basemap'])
-    is_crs = CRS is not object and isinstance(name, CRS)
+    basemap = _not_none(basemap, rc['basemap'])
+    is_crs = Projection is not object and isinstance(name, Projection)
     is_basemap = Basemap is not object and isinstance(name, Basemap)
-    include_axes = kwargs.pop('include_axes', None)
+    include_axes = kwargs.pop('include_axes', False)  # for error message
     if is_crs or is_basemap:
         proj = name
-        proj._proj_package = 'cartopy' if is_crs else 'basemap'
-        if basemap is not None:
-            kwargs['basemap'] = basemap
+        package = 'cartopy' if is_crs else 'basemap'
         if kwargs:
             warnings._warn_proplot(f'Ignoring Proj() keyword arg(s): {kwargs!r}.')
 
-    # Invalid
+    # Unknown
     elif not isinstance(name, str):
         raise ValueError(
-            f'Unexpected Proj() argument {name!r}. '
-            'Must be name, mpl_toolkits.basemap.Basemap instance, '
-            'or cartopy.crs.CRS instance.'
+            f'Unexpected projection {name!r}. Must be PROJ string name, '
+            'cartopy.crs.Projection, or mpl_toolkits.basemap.Basemap.'
         )
 
     # Basemap
-    elif use_basemap:
-        # NOTE: Known issue that basemap sometimes produces backwards maps:
-        # https://stackoverflow.com/q/56299971/4970632
-        # NOTE: We set rsphere to fix non-conda installed basemap issue:
-        # https://github.com/matplotlib/basemap/issues/361
-        # NOTE: Unlike cartopy, basemap resolution is configured on
-        # initialization and controls *all* features.
+    # NOTE: Known issue that basemap sometimes produces backwards maps:
+    # https://stackoverflow.com/q/56299971/4970632
+    # NOTE: We set rsphere to fix non-conda installed basemap issue:
+    # https://github.com/matplotlib/basemap/issues/361
+    # NOTE: Adjust lon_0 tof fix issues with Robinson (and related?) projections
+    # https://stackoverflow.com/questions/56299971/ (also triggers 'no room for axes')
+    # NOTE: Unlike cartopy, basemap resolution is configured
+    # on initialization and controls *all* features.
+    elif basemap:
         import mpl_toolkits.basemap as mbasemap
+        package = 'basemap'
         if dependencies._version_mpl >= 3.3:
             raise RuntimeError(
                 'Basemap is no longer maintained and is incompatible with '
@@ -1431,21 +1442,18 @@ def Proj(name, basemap=None, **kwargs):
         if 'latlim' in kwargs:
             kwargs['llcrnrlat'], kwargs['urcrnrlat'] = kwargs.pop('latlim')
         name = PROJ_ALIASES.get(name, name)
-        kwproj = PROJ_DEFAULTS.get(name, {}).copy()
-        kwproj.update(kwargs)
-        kwproj.setdefault('fix_aspect', True)
-        if kwproj.get('lon_0', 0) > 0:
-            # Fix issues with Robinson (and related?) projections
-            # See: https://stackoverflow.com/questions/56299971/
-            # Get both this issue *and* 'no room for axes' issue
-            kwproj['lon_0'] -= 360
+        proj_kw = PROJ_DEFAULTS.get(name, {}).copy()
+        proj_kw.update(kwargs)
+        proj_kw.setdefault('fix_aspect', True)
+        if proj_kw.get('lon_0', 0) > 0:
+            proj_kw['lon_0'] -= 360
         if name[:2] in ('np', 'sp'):
-            kwproj.setdefault('round', True)
+            proj_kw.setdefault('round', True)
         if name == 'geos':
-            kwproj.setdefault('rsphere', (6378137.00, 6356752.3142))
+            proj_kw.setdefault('rsphere', (6378137.00, 6356752.3142))
         reso = _not_none(
-            reso=kwproj.pop('reso', None),
-            resolution=kwproj.pop('resolution', None),
+            reso=proj_kw.pop('reso', None),
+            resolution=proj_kw.pop('resolution', None),
             default=rc['reso']
         )
         if reso in RESOS_BASEMAP:
@@ -1456,42 +1464,47 @@ def Proj(name, basemap=None, **kwargs):
                 + ', '.join(map(repr, RESOS_BASEMAP))
                 + '.'
             )
-        kwproj.update({'resolution': reso, 'projection': name})
-        proj = mbasemap.Basemap(**kwproj)
-        proj._proj_package = 'basemap'
+        proj_kw.update({'resolution': reso, 'projection': name})
+        try:
+            proj = mbasemap.Basemap(**proj_kw)  # will raise helpful warning
+        except ValueError as err:
+            message = str(err)
+            message = message.strip()
+            message = message.replace('projection', 'basemap projection')
+            message = message.replace('supported', 'known')
+            if include_axes:
+                from . import axes as paxes  # avoid circular imports
+                message = message.replace('projection.', 'projection or axes subclass.')
+                message += '\nThe known axes subclasses are:\n' + paxes._cls_table
+            raise ValueError(message) from None
 
     # Cartopy
-    elif name in PROJS:
-        import cartopy.crs  # noqa: F401
-        kwproj = {
-            PROJ_ALIASES_KW.get(key, key): value
-            for key, value in kwargs.items()
-        }
-        crs = PROJS.get(name, None)
-        if name == 'geos':  # fix common mistake
-            kwproj.pop('central_latitude', None)
-        if 'boundinglat' in kwproj:
-            raise ValueError(
-                '"boundinglat" must be passed to the ax.format() command '
-                'for cartopy axes.'
-            )
-        proj = crs(**kwproj)
-        proj._proj_package = 'cartopy'
-
-    # Unknown
+    # NOTE: Error message matches basemap invalid projection message
     else:
-        options = tuple(PROJS)
-        if include_axes:
-            options += tuple(
-                proj.split('proplot_', 1)[1] for proj in mproj.get_projection_names()
-                if 'proplot_' in proj
+        import cartopy.crs as ccrs  # noqa: F401
+        package = 'cartopy'
+        proj_kw = {PROJ_ALIASES_KW.get(key, key): value for key, value in kwargs.items()}  # noqa: E501
+        if 'boundinglat' in proj_kw:
+            raise ValueError('"boundinglat" must be passed to the ax.format() command for cartopy axes.')  # noqa: E501
+        try:
+            crs = PROJS[name]
+        except KeyError:
+            message = f'{name!r} is an unknown cartopy projection class.\n'
+            message += 'The known cartopy projection classes are:\n'
+            message += '\n'.join(
+                ' ' + key + ' ' * (max(map(len, PROJS)) - len(key) + 10) + cls.__name__
+                for key, cls in PROJS.items()
             )
-        raise ValueError(
-            f'Unknown projection {name!r}. Options are: '
-            + ', '.join(map(repr, options))
-            + '.'
-        )
+            if include_axes:
+                from . import axes as paxes  # avoid circular imports
+                message = message.replace('class.', 'class or axes subclass.')
+                message += '\nThe known axes subclasses are:\n' + paxes._cls_table
+            raise ValueError(message) from None
+        if name == 'geos':  # fix common mistake
+            proj_kw.pop('central_latitude', None)
+        proj = crs(**proj_kw)
 
+    proj._proj_package = package
     return proj
 
 
