@@ -28,7 +28,7 @@ from .internals import (
     context,
     dependencies,
     docstring,
-    textmods,
+    texts,
     warnings,
 )
 from .utils import units
@@ -222,7 +222,17 @@ order : {'C', 'F'}, optional
 docstring._snippet_manager['figure.subplots_params'] = _subplots_params_docstring
 
 
-# Composed subplots docstring
+# Extra args docstring
+_axes_params_docstring = """
+**kwargs
+    Passed to the proplot class `proplot.axes.CartesianAxes`, `proplot.axes.PolarAxes`,
+    `proplot.axes.GeoAxes`, or `proplot.axes.ThreeAxes`. This can include keyword
+    arguments for projection-specific ``format`` commands.
+"""
+docstring._snippet_manager['figure.axes_params'] = _axes_params_docstring
+
+
+# Multiple subplots docstring
 _subplots_docstring = """
 Add an arbitrary grid of subplots to the figure.
 
@@ -233,27 +243,26 @@ Parameters
 Other parameters
 ----------------
 %(figure.figure)s
-**kwargs
-    Passed to `Figure.add_subplot`.
+%(figure.axes_params)s
 
 Returns
 -------
-axs : `SubplotGrid`
+axs : SubplotGrid
     The axes instances stored in a `SubplotGrid`.
 
 See also
 --------
 proplot.ui.figure
 proplot.ui.subplots
-proplot.figure.Figure
-matplotlib.figure.Figure
+proplot.figure.Figure.subplot
+proplot.figure.Figure.add_subplot
 proplot.gridspec.SubplotGrid
 proplot.axes.Axes
 """
 docstring._snippet_manager['figure.subplots'] = _subplots_docstring
 
 
-# Single subplots
+# Single subplot docstring
 _subplot_docstring = """
 Add a subplot axes to the figure.
 
@@ -295,8 +304,13 @@ autoshare : bool, optional
 
 Other parameters
 ----------------
-**kwargs
-    Passed to `matplotlib.axes.Axes`.
+%(figure.axes_params)s
+
+See also
+--------
+proplot.figure.Figure.add_axes
+proplot.figure.Figure.subplots
+proplot.figure.Figure.add_subplots
 """
 docstring._snippet_manager['figure.subplot'] = _subplot_docstring
 
@@ -313,6 +327,17 @@ rect : 4-tuple of float
 %(axes.proj)s
 %(axes.proj_kw)s
 %(axes.basemap)s
+
+Other parameters
+----------------
+%(figure.axes_params)s
+
+See also
+--------
+proplot.figure.Figure.subplot
+proplot.figure.Figure.add_subplot
+proplot.figure.Figure.subplots
+proplot.figure.Figure.add_subplots
 """
 docstring._snippet_manager['figure.axes'] = _axes_docstring
 
@@ -747,22 +772,36 @@ class Figure(mfigure.Figure):
             raise ValueError('Matplotlib axes cannot be added to proplot figures.')
 
         # Search axes projections
-        if not isinstance(proj, str):
-            name = None
-        else:
-            name = 'proplot_' + proj
+        name = None
+        if isinstance(proj, str):
             try:
-                mproj.get_projection_class(name)
+                mproj.get_projection_class('proplot_' + proj)
             except (KeyError, ValueError):
-                name = None
-
-        # Redirect to basemap or cartopy projection
+                pass
+            else:
+                name = proj
+        # Helpful error message
+        if (
+            name is None
+            and basemap is None
+            and isinstance(proj, str)
+            and constructor.Projection is object
+            and constructor.Basemap is object
+        ):
+            raise ValueError(
+                f'Invalid projection name {proj!r}. If you are trying to generate a '
+                'GeoAxes with a cartopy.crs.Projection or mpl_toolkits.basemap.Basemap '
+                'then cartopy or basemap must be installed. Otherwise the known axes '
+                f'subclasses are:\n{paxes._cls_table}'
+            )
+        # Search geographic projections
+        # NOTE: Also raises errors due to unexpected projection type
         if name is None:
             proj = constructor.Proj(proj, basemap=basemap, include_axes=True, **proj_kw)
-            name = 'proplot_' + proj._proj_package
+            name = proj._proj_package
             kwargs['map_projection'] = proj
 
-        kwargs['projection'] = name
+        kwargs['projection'] = 'proplot_' + name
         return kwargs
 
     def _get_align_axes(self, side):
@@ -986,7 +1025,7 @@ class Figure(mfigure.Figure):
         # 'super' labels and replace the actual labels with spaces so they still impact
         # the tight bounding box and thus allocate space for the spanning label.
         x, y = 'xy' if side in ('bottom', 'top') else 'yx'
-        labs = getattr(self, '_sup' + x + 'label_dict')  # dict of spanning labels
+        labs = getattr(self, f'_sup{x}label_dict')  # dict of spanning labels
         setpos = getattr(mtext.Text, 'set_' + y)
         axislist = [getattr(ax, x + 'axis') for ax in axs]
 
@@ -1007,7 +1046,7 @@ class Figure(mfigure.Figure):
         # Copy text from central label to spanning label
         # NOTE: Must use spaces rather than newlines, otherwise tight layout
         # won't make room. Reason is Text implementation (see Text._get_layout())
-        textmods._transfer_text(axis.label, label)  # text, color, and font properties
+        texts._transfer_text(axis.label, label)  # text, color, and font properties
         space = '\n'.join(' ' * (1 + label.get_text().count('\n')))
         for axis in axislist:  # should include original 'axis'
             axis.label.set_text(space)
@@ -1282,7 +1321,7 @@ class Figure(mfigure.Figure):
             array = array.reshape((nrows, ncols), order=order)
         array = np.atleast_1d(array)
         array[array == None] = 0  # None or 0 both valid placeholders  # noqa: E711
-        array = array.astype(np.int)
+        array = array.astype(int)
         if array.ndim == 1:  # interpret as single row or column
             array = array[None, :] if order == 'C' else array[:, None]
         elif array.ndim != 2:
@@ -1306,6 +1345,8 @@ class Figure(mfigure.Figure):
 
         # Create gridspec and add subplots with subplotspecs
         # NOTE: The gridspec is added to the figure when we pass the subplotspec
+        # NOTE: Permit figure format keywords for e.g. 'collabels'
+        figure_kw = _pop_params(kwargs, self._format_signature)
         gridspec_kw = _pop_params(kwargs, pgridspec.GridSpec._update_params)
         gs = pgridspec.GridSpec(nrows, ncols, **gridspec_kw)
         axs = naxs * [None]  # list of axes
@@ -1320,6 +1361,7 @@ class Figure(mfigure.Figure):
             kw = {**kwargs, **axes_kw[num], 'number': num}
             axs[idx] = self.add_subplot(ss, **kw)
 
+        self.format(**figure_kw)
         return pgridspec.SubplotGrid(axs)
 
     @docstring._snippet_manager
@@ -1394,7 +1436,7 @@ class Figure(mfigure.Figure):
 
     @docstring._snippet_manager
     def format(
-        self, axs=None,
+        self, axs=None, *,
         figtitle=None, suptitle=None, suptitle_kw=None,
         llabels=None, leftlabels=None, leftlabels_kw=None,
         rlabels=None, rightlabels=None, rightlabels_kw=None,
@@ -1410,15 +1452,8 @@ class Figure(mfigure.Figure):
         Parameters
         ----------
         axs : sequence of `~proplot.axes.Axes`, optional
-            The axes to format.
+            The axes to format. Default is the numbered subplots.
         %(figure.format)s
-        **kwargs
-            Passed to the projection-specific ``format`` command for each axes.
-
-        Other parameters
-        ----------------
-        %(axes.format)s
-        %(axes.rc)s
 
         Important
         ---------
@@ -1428,6 +1463,14 @@ class Figure(mfigure.Figure):
         change them for specific figures. But many :ref:`other configuration
         settings <ug_format>` can be passed to ``format`` too.
 
+        Other parameters
+        ----------------
+        %(axes.format)s
+        %(cartesian.format)s
+        %(polar.format)s
+        %(geo.format)s
+        %(rc.format)s
+
         See also
         --------
         proplot.axes.Axes.format
@@ -1438,6 +1481,7 @@ class Figure(mfigure.Figure):
         proplot.config.Configurator.context
         """
         # Initiate context block
+        axs = axs or self._subplot_dict.values()
         skip_axes = kwargs.pop('skip_axes', False)  # internal keyword arg
         rc_kw, rc_mode = _pop_rc(kwargs)
         with rc.context(rc_kw, mode=rc_mode):
@@ -1498,9 +1542,28 @@ class Figure(mfigure.Figure):
         # Update the main axes
         if skip_axes:  # avoid recursion
             return
-        axs = axs or self._subplot_dict.values()
+        kws = {
+            cls: _pop_params(kwargs, sig)
+            for cls, sig in paxes.Axes._format_signatures.items()
+        }
+        classes = set()  # track used dictionaries
         for ax in axs:
-            ax.format(rc_kw=rc_kw, rc_mode=rc_mode, skip_figure=True, **kwargs)
+            kw = {
+                key: value for cls, kw in kws.items()
+                for key, value in kw.items()
+                if isinstance(ax, cls) and not classes.add(cls)
+            }
+            ax.format(rc_kw=rc_kw, rc_mode=rc_mode, skip_figure=True, **kw, **kwargs)
+
+        # Warn unused keyword argument(s)
+        kw = {
+            key: value for name in kws.keys() - classes
+            for key, value in kws[name].items()
+        }
+        if kw:
+            warnings._warn_proplot(
+                f'Ignoring unused projection-specific format() keyword argument(s): {kw}'  # noqa: E501
+            )
 
     @docstring._concatenate_inherited
     @docstring._snippet_manager
