@@ -1109,7 +1109,7 @@ class GridSpec(mgridspec.GridSpec):
     @property
     def figure(self):
         """
-        The `proplot.figure.Figure` instance uniquely associated with this `GridSpec`.
+        The `proplot.figure.Figure` uniquely associated with this `GridSpec`.
         On assignment the gridspec parameters and figure size are updated.
         """
         return self._figure
@@ -1283,7 +1283,7 @@ class SubplotGrid(MutableSequence, list):
 
         Returns
         -------
-        axs : `~proplot.axes.Axes` or `SubplotGrid`
+        axs : proplot.axes.Axes or SubplotGrid
             The axes. If the index included slices then
             another `SubplotGrid` is returned.
 
@@ -1291,9 +1291,9 @@ class SubplotGrid(MutableSequence, list):
         -------
         >>> import proplot as pplt
         >>> fig, axs = pplt.subplots(nrows=3, ncols=3)
-        >>> axs[3]  # the subplots in the second row, first column
-        >>> axs[1, 2]  # the subplots in the second row, third column
-        >>> axs[:, 0]  # a grid of subplots in the first column
+        >>> axs[5]  # the Axes in the second row, third column
+        >>> axs[1, 2]  # the Axes in the second row, third column
+        >>> axs[:, 0]  # a SubplotGrid containing the Axes in the first column
         """
         if isinstance(key, tuple) and len(key) == 1:
             key = key[0]
@@ -1359,20 +1359,22 @@ class SubplotGrid(MutableSequence, list):
         gridspec = None
         message = (
             'SubplotGrid can only be filled with proplot subplots '
-            'belonging to the same GridSpec. Instead got {!r}.'
+            'belonging to the same GridSpec. Instead got {}.'
         )
         items = np.atleast_1d(items)
         if self:
             gridspec = self.gridspec  # compare against existing gridspec
         for item in items.flat:
             if not isinstance(item, paxes.Axes):
-                raise ValueError(message.format(item))
+                raise ValueError(message.format(f'the object {item!r}'))
             item = item._get_topmost_axes()
             if not isinstance(item, maxes.SubplotBase):
-                raise ValueError(message.format(item))
+                raise ValueError(message.format(f'the axes {item!r}'))
             gs = item.get_subplotspec().get_gridspec()
-            if not isinstance(gs, GridSpec) or (gridspec and gs is not gridspec):
-                raise ValueError(message.format(gs))
+            if not isinstance(gs, GridSpec):
+                raise ValueError(message.format(f'the GridSpec {gs!r}'))
+            if gridspec and gs is not gridspec:
+                raise ValueError(message.format('at least two different GridSpecs'))
             gridspec = gs
         if not scalar:
             items = tuple(items.flat)
@@ -1383,7 +1385,7 @@ class SubplotGrid(MutableSequence, list):
         return items
 
     @docstring._snippet_manager
-    def format(self, *args, **kwargs):
+    def format(self, **kwargs):
         """
         Call the ``format`` command for every axes in the grid.
 
@@ -1397,7 +1399,10 @@ class SubplotGrid(MutableSequence, list):
         Other parameters
         ----------------
         %(figure.format)s
-        %(axes.rc)s
+        %(cartesian.format)s
+        %(polar.format)s
+        %(geo.format)s
+        %(rc.format)s
 
         See also
         --------
@@ -1408,14 +1413,21 @@ class SubplotGrid(MutableSequence, list):
         proplot.figure.Figure.format
         proplot.config.Configurator.context
         """
-        for ax in self:
-            ax.format(*args, **kwargs)
+        self.figure.format(axs=self, **kwargs)
+
+    @property
+    def figure(self):
+        """
+        The `proplot.figure.Figure` uniquely associated with this `SubplotGrid`.
+        This is used for the `SubplotGrid.format` command.
+        """
+        return self.gridspec.figure
 
     @property
     def gridspec(self):
         """
-        The `~proplot.gridspec.GridSpec` associated with the grid. This is used
-        to resolve 2D indexing. See `~SubplotGrid.__getitem__` for details.
+        The `~proplot.gridspec.GridSpec` uniquely associated with this `SubplotGrid`.
+        This is used to resolve 2D indexing. See `~SubplotGrid.__getitem__` for details.
         """
         # Return the gridspec associatd with the grid
         if not self:
@@ -1436,6 +1448,9 @@ class SubplotGrid(MutableSequence, list):
 
 
 def _add_grid_command(src, name):
+    """
+    Add a `SubplotGrid` method that iterates through axes methods.
+    """
     # Create the method
     def _grid_command(self, *args, **kwargs):
         objs = []
