@@ -21,7 +21,7 @@ from . import (  # noqa: F401
     guides,
     process,
     rcsetup,
-    textmods,
+    texts,
     warnings
 )
 
@@ -289,6 +289,8 @@ def _pop_params(kwargs, *funcs, ignore_internal=False):
             sig = func
         elif callable(func):
             sig = inspect.signature(func)
+        elif func is None:
+            continue
         else:
             raise RuntimeError(f'Internal error. Invalid function {func!r}.')
         for key in sig.parameters:
@@ -338,12 +340,24 @@ def _pop_props(input, *categories, prefix=None, ignore=None, skip=None):
     return output
 
 
-def _pop_rc(src):
+def _pop_rc(src, *, ignore_conflicts=True):
     """
     Pop the rc setting names and mode for a `~Configurator.context` block.
     """
+    # NOTE: Must ignore deprected or conflicting rc params
     # NOTE: rc_mode == 2 applies only the updated params. A power user
     # could use ax.format(rc_mode=0) to re-apply all the current settings
+    conflict_params = (
+        'alpha',
+        'color',
+        'facecolor',
+        'edgecolor',
+        'linewidth',
+        'share',
+        'span',
+        'tight',
+        'span',
+    )
     kw = src.pop('rc_kw', None) or {}
     if 'mode' in src:
         src['rc_mode'] = src.pop('mode')
@@ -354,7 +368,7 @@ def _pop_rc(src):
     mode = _not_none(mode, 2)  # only apply updated params by default
     for key, value in tuple(src.items()):
         name = rcsetup._rc_nodots.get(key, None)
-        if name in ('alpha', 'color', 'facecolor', 'edgecolor', 'linewidth'):
+        if ignore_conflicts and name in conflict_params:
             name = None  # former renamed settings
         if name is not None:
             kw[name] = src.pop(key)
