@@ -1,9 +1,11 @@
 #!/usr/bin/env python3
 """
-Utilities for benchmarking ProPlot performance.
+Utilities for benchmarking proplot performance.
 """
 import time
 
+from . import ic  # noqa: F401
+
 BENCHMARK = False  # toggle this to turn on benchmarking (see timers.py)
 
 
