@@ -34,9 +34,9 @@ REGEX_NAMED_COLOR = re.compile(r'\A[a-zA-Z0-9:_ -]*\Z')
 BLACK = 'black'
 CYCLE = 'colorblind'
 CMAPCYC = 'twilight'
-CMAPDIV = 'negpos'
-CMAPSEQ = 'fire'
-CMAPCAT = 'flatui'
+CMAPDIV = 'BuRd'
+CMAPSEQ = 'Fire'
+CMAPCAT = 'colorblind10'
 DIVERGING = 'div'
 FRAMEALPHA = 0.8  # legend and colorbar
 FONTNAME = 'sans-serif'
@@ -1870,11 +1870,11 @@ if dependencies._version_mpl >= 3.4:
 # translate deprecated keys in Configurator -- leave that to the RcParams dicts.
 _rc_removed = {  # {key: (alternative, version)} dictionary
     'rgbcycle': ('', '0.6'),  # no alternative, we no longer offer this feature
-    'geogrid.latmax': ('Please use ax.format(latmax=N) instead.', '0.6'),
-    'geogrid.latstep': ('Please use ax.format(latlines=N) instead.', '0.6'),
-    'geogrid.lonstep': ('Please use ax.format(lonlines=N) instead.', '0.6'),
-    'gridminor.latstep': ('Please use ax.format(latminorlines=N) instead.', '0.6'),
-    'gridminor.lonstep': ('Please use ax.format(lonminorlines=N) instead.', '0.6'),
+    'geogrid.latmax': ('Please use e.g. ax.format(latmax=N) instead.', '0.6'),
+    'geogrid.latstep': ('Please use e.g. ax.format(latlines=N) instead.', '0.6'),
+    'geogrid.lonstep': ('Please use e.g. ax.format(lonlines=N) instead.', '0.6'),
+    'gridminor.latstep': ('Please use e.g. ax.format(latminorlines=N) instead.', '0.6'),
+    'gridminor.lonstep': ('Please use e.g. ax.format(lonminorlines=N) instead.', '0.6'),
 }
 _rc_renamed = {  # {old_key: (new_key, version)} dictionary
     'abc.format': ('abc', '0.5'),
@@ -1926,11 +1926,13 @@ for _key, (_key_new, _) in _rc_renamed.items():
         _rc_children[_key] = _rc_children[_key_new]
 
 # The default settings dictionary. Analogous to matplotlib's rcParamsDefault
+# Also surreptitiously add font keys (boolean always evaluates to True)
 _rc_proplot_default = {
     key: value for key, (value, _, _) in _rc_proplot_table.items()
 }
 _rc_proplot_validate = {
     key: validator for key, (_, validator, _) in _rc_proplot_table.items()
+    if not (validator is _validate_fontsize and FONT_KEYS.add(key))
 }
 _rc_proplot_default = _RcParams(_rc_proplot_default, _rc_proplot_validate)
 
